@@ -68,7 +68,7 @@ function create_trove_accounts {
 # restart apache.
 function _cleanup_trove_apache_wsgi {
     sudo rm -rf $TROVE_WSGI_DIR
-    sudo rm -f ${apache_site_config_for trove-api}
+    sudo rm -f $(apache_site_config_for trove-api)
     restart_apache_server
 }
 
@@ -79,7 +79,6 @@ function _cleanup_trove_apache_wsgi {
 # runs that a clean run would need to clean up
 function cleanup_trove {
     # Clean up dirs
-    rm -fr $TROVE_AUTH_CACHE_DIR/*
     rm -fr $TROVE_CONF_DIR/*
 
     if is_service_enabled horizon; then
@@ -119,6 +118,9 @@ function configure_keystone_token_life() {
     KEYSTONE_TOKEN_LIFE=${KEYSTONE_TOKEN_LIFE:-10800}
     iniset $KEYSTONE_CONF token expiration ${KEYSTONE_TOKEN_LIFE}
     echo "configure_keystone_token_life: setting keystone token life to ${KEYSTONE_TOKEN_LIFE}"
+    echo "configure_keystone_token_life: restarting Keystone"
+    stop_keystone
+    start_keystone
 }
 
 # configure_nova_kvm() - update the nova hypervisor configuration if possible
@@ -177,18 +179,17 @@ function _config_trove_apache_wsgi {
 function configure_trove {
     setup_develop $TROVE_DIR
 
-    configure_nova_kvm
+    # Temporarily disable re-configuring nova_kvm until
+    # more nodes in the pool can support it without crashing.
+    # configure_nova_kvm
     configure_keystone_token_life
 
     # Create the trove conf dir and cache dirs if they don't exist
-    sudo install -d -o $STACK_USER ${TROVE_CONF_DIR} ${TROVE_AUTH_CACHE_DIR}
+    sudo install -d -o $STACK_USER ${TROVE_CONF_DIR}
 
     # Copy api-paste file over to the trove conf dir
     cp $TROVE_LOCAL_API_PASTE_INI $TROVE_API_PASTE_INI
 
-    # Copy the default policy file over to the trove conf dir
-    cp $TROVE_LOCAL_POLICY_JSON $TROVE_POLICY_JSON
-
     # (Re)create trove conf files
     rm -f $TROVE_CONF
     rm -f $TROVE_TASKMANAGER_CONF
@@ -215,7 +216,7 @@ function configure_trove {
         setup_trove_logging $TROVE_CONF
         iniset $TROVE_CONF DEFAULT trove_api_workers "$API_WORKERS"
 
-        configure_auth_token_middleware $TROVE_CONF trove $TROVE_AUTH_CACHE_DIR
+        configure_auth_token_middleware $TROVE_CONF trove
         iniset $TROVE_CONF DEFAULT trove_auth_url $TROVE_AUTH_ENDPOINT
     fi
 
@@ -282,6 +283,7 @@ function configure_trove {
 
     # Use these values only if they're set
     iniset_conditional $TROVE_GUESTAGENT_CONF DEFAULT state_change_wait_time $TROVE_STATE_CHANGE_WAIT_TIME
+    iniset_conditional $TROVE_GUESTAGENT_CONF DEFAULT command_process_timeout $TROVE_COMMAND_PROCESS_TIMEOUT
 
     # Set up Guest Agent conf
     iniset $TROVE_GUESTAGENT_CONF DEFAULT rpc_backend "rabbit"
