@@ -17,6 +17,7 @@ import six
 
 from oslo_log import log as logging
 
+from neutronclient.common import exceptions as neutron_exceptions
 from novaclient import exceptions as nova_exceptions
 from trove.cluster.tasks import ClusterTask
 from trove.cluster.tasks import ClusterTasks
@@ -147,11 +148,11 @@ class Cluster(object):
         self.db_info.save()
 
     def reset_task(self):
-        LOG.info(_("Setting task to NONE on cluster %s"), self.id)
+        LOG.info("Setting task to NONE on cluster %s", self.id)
         self.update_db(task_status=ClusterTasks.NONE)
 
     def reset_status(self):
-        LOG.info(_("Resetting status to NONE on cluster %s"), self.id)
+        LOG.info("Resetting status to NONE on cluster %s", self.id)
         self.reset_task()
         instances = inst_models.DBInstance.find_all(cluster_id=self.id,
                                                     deleted=False).all()
@@ -271,11 +272,13 @@ class Cluster(object):
 
     def validate_cluster_available(self, valid_states=[ClusterTasks.NONE]):
         if self.db_info.task_status not in valid_states:
-            msg = (_("This action cannot be performed on the cluster while "
-                     "the current cluster task is '%s'.") %
-                   self.db_info.task_status.name)
-            LOG.error(msg)
-            raise exception.UnprocessableEntity(msg)
+            log_fmt = ("This action cannot be performed on the cluster while "
+                       "the current cluster task is '%s'.")
+            exc_fmt = _("This action cannot be performed on the cluster while "
+                        "the current cluster task is '%s'.")
+            LOG.error(log_fmt, self.db_info.task_status.name)
+            raise exception.UnprocessableEntity(
+                exc_fmt % self.db_info.task_status.name)
 
     def delete(self):
 
@@ -649,3 +652,22 @@ def validate_volume_size(size):
                "of %d Gb, %s cannot be accepted."
                % (max_size, size))
         raise exception.VolumeQuotaExceeded(msg)
+
+
+def validate_instance_nics(context, instances):
+    """Checking networks are same for the cluster."""
+    instance_nics = []
+    for instance in instances:
+        nics = instance.get('nics')
+        if nics:
+            instance_nics.append(nics[0].get('net-id'))
+    if len(set(instance_nics)) > 1:
+        raise exception.ClusterNetworksNotEqual()
+    if not instance_nics:
+        return
+    instance_nic = instance_nics[0]
+    try:
+        neutron_client = remote.create_neutron_client(context)
+        neutron_client.find_resource('network', instance_nic)
+    except neutron_exceptions.NotFound:
+        raise exception.NetworkNotFound(uuid=instance_nic)
