@@ -29,7 +29,6 @@ import time
 import eventlet.wsgi
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_log import loggers
 from oslo_serialization import jsonutils
 from oslo_service import service
 from oslo_service import sslutils
@@ -42,6 +41,7 @@ from xml.parsers import expat
 
 from trove.common import base_exception
 from trove.common.i18n import _
+from trove.common.utils import req_to_text
 from trove.common import xmlutils
 
 socket_opts = [
@@ -159,7 +159,7 @@ class Service(service.Service):
         eventlet.wsgi.server(socket,
                              application,
                              custom_pool=self.tg.pool,
-                             log=loggers.WritableLogger(logger))
+                             log=logger)
 
 
 class Middleware(object):
@@ -211,7 +211,7 @@ class Debug(Middleware):
         resp = req.get_response(self.application)
 
         print(("*" * 40) + " RESPONSE HEADERS")
-        for (key, value) in resp.headers.iteritems():
+        for (key, value) in resp.headers.items():
             print(key, "=", value)
         print()
 
@@ -333,6 +333,8 @@ class Request(webob.Request):
             raise base_exception.InvalidContentType(content_type=content_type)
         return content_type
 
+    __str__ = req_to_text
+
 
 class Resource(object):
     """
