@@ -70,21 +70,29 @@ common_opts = [
                help="The version of the compute service client."),
     cfg.StrOpt('glance_client_version', default='2',
                help="The version of the image service client."),
+    cfg.BoolOpt('nova_api_insecure', default=False,
+                help="Allow to perform insecure SSL requests to nova."),
     cfg.URIOpt('neutron_url', help='URL without the tenant segment.'),
     cfg.StrOpt('neutron_service_type', default='network',
                help='Service type to use when searching catalog.'),
     cfg.StrOpt('neutron_endpoint_type', default='publicURL',
                help='Service endpoint type to use when searching catalog.'),
+    cfg.BoolOpt('neutron_api_insecure', default=False,
+                help="Allow to perform insecure SSL requests to neutron."),
     cfg.URIOpt('cinder_url', help='URL without the tenant segment.'),
     cfg.StrOpt('cinder_service_type', default='volumev2',
                help='Service type to use when searching catalog.'),
     cfg.StrOpt('cinder_endpoint_type', default='publicURL',
                help='Service endpoint type to use when searching catalog.'),
+    cfg.BoolOpt('cinder_api_insecure', default=False,
+                help="Allow to perform insecure SSL requests to cinder."),
     cfg.URIOpt('swift_url', help='URL ending in ``AUTH_``.'),
     cfg.StrOpt('swift_service_type', default='object-store',
                help='Service type to use when searching catalog.'),
     cfg.StrOpt('swift_endpoint_type', default='publicURL',
                help='Service endpoint type to use when searching catalog.'),
+    cfg.BoolOpt('swift_api_insecure', default=False,
+                help="Allow to perform insecure SSL requests to swift."),
     cfg.URIOpt('glance_url', help='URL ending in ``AUTH_``.'),
     cfg.StrOpt('glance_service_type', default='image',
                help='Service type to use when searching catalog.'),
@@ -160,6 +168,9 @@ common_opts = [
     cfg.IntOpt('agent_replication_snapshot_timeout', default=36000,
                help='Maximum time (in seconds) to wait for taking a Guest '
                     'Agent replication snapshot.'),
+    cfg.IntOpt('command_process_timeout', default=30,
+               help='Maximum time (in seconds) to wait for out of process '
+                    'commands to complete.'),
     # The guest_id opt definition must match the one in cmd/guest.py
     cfg.StrOpt('guest_id', default=None, help="ID of the Guest Instance."),
     cfg.IntOpt('state_change_wait_time', default=60 * 10,
@@ -278,6 +289,10 @@ common_opts = [
                 help='Enable verification of Swift checksum before starting '
                 'restore. Makes sure the checksum of original backup matches '
                 'the checksum of the Swift backup file.'),
+    cfg.BoolOpt('verify_replica_volume_size', default=True,
+                help='Require the replica volume size to be greater than '
+                'or equal to the size of the master volume '
+                'during replica creation.'),
     cfg.StrOpt('storage_strategy', default='SwiftStorage',
                help="Default strategy to store backups."),
     cfg.StrOpt('storage_namespace',
@@ -354,6 +369,11 @@ common_opts = [
                help="Admin tenant ID used to connect to Nova.", secret=True),
     cfg.StrOpt('nova_proxy_admin_tenant_name', default='',
                help="Admin tenant name used to connect to Nova.", secret=True),
+    cfg.StrOpt('nova_proxy_admin_user_domain_name', default='Default',
+               help="User domain of the admin user used to connect to Nova."),
+    cfg.StrOpt('nova_proxy_admin_project_domain_name', default='Default',
+               help="Project domain of the admin user used to connect to "
+                    "Nova."),
     cfg.StrOpt('network_label_regex', default='^private$',
                help='Regular expression to match Trove network labels.'),
     cfg.StrOpt('ip_regex', default=None,
@@ -837,7 +857,7 @@ redis_opts = [
                help='Class that implements datastore-specific Guest Agent API '
                     'logic.'),
     cfg.StrOpt('root_controller',
-               default='trove.extensions.common.service.DefaultRootController',
+               default='trove.extensions.redis.service.RedisRootController',
                help='Root controller implementation for redis.'),
     cfg.StrOpt('guest_log_exposed_logs', default='',
                help='List of Guest Logs to expose for publishing.'),
@@ -1580,8 +1600,8 @@ def get_configuration_property(property_name):
     datastore_manager = CONF.datastore_manager
     if not datastore_manager:
         datastore_manager = 'mysql'
-        LOG.warning(_("Manager name ('datastore_manager') not defined, "
-                      "using '%s' options instead."), datastore_manager)
+        LOG.warning("Manager name ('datastore_manager') not defined, "
+                    "using '%s' options instead.", datastore_manager)
 
     try:
         return CONF.get(datastore_manager).get(property_name)
