@@ -93,8 +93,9 @@ class DatabaseNotFound(NotFound):
 
 class ComputeInstanceNotFound(NotFound):
 
-    internal_message = _("Cannot find compute instance %(server_id)s for "
-                         "instance %(instance_id)s.")
+    # internal_message is used for log, stop translating.
+    internal_message = ("Cannot find compute instance %(server_id)s for "
+                        "instance %(instance_id)s.")
 
     message = _("Resource %(instance_id)s can not be retrieved.")
 
@@ -202,8 +203,15 @@ class NoUniqueMatch(TroveError):
 
 class OverLimit(TroveError):
 
-    internal_message = _("The server rejected the request due to its size or "
-                         "rate.")
+    # internal_message is used for log, stop translating.
+    internal_message = ("The server rejected the request due to its size or "
+                        "rate.")
+
+
+class QuotaLimitTooSmall(TroveError):
+
+    message = _("Quota limit '%(limit)s' for '%(resource)s' is too small"
+                " - must be at least '-1'.")
 
 
 class QuotaExceeded(TroveError):
@@ -436,6 +444,10 @@ class BackupDatastoreMismatchError(TroveError):
                 " datastore of %(datastore2)s.")
 
 
+class ReplicaCreateWithUsersDatabasesError(TroveError):
+    message = _("Cannot create a replica with users or databases.")
+
+
 class SwiftAuthError(TroveError):
     message = _("Swift account not accessible for tenant %(tenant_id)s.")
 
@@ -661,3 +673,9 @@ class DatastoreVersionAlreadyExists(BadRequest):
 class LogAccessForbidden(Forbidden):
 
     message = _("You must be admin to %(action)s log '%(log)s'.")
+
+
+class SlaveOperationNotSupported(TroveError):
+
+    message = _("The '%(operation)s' operation is not supported for slaves in "
+                "replication.")
