@@ -21,6 +21,7 @@ from trove.common.strategies.cluster import strategy
 
 from cinderclient.v2 import client as CinderClient
 from keystoneclient.service_catalog import ServiceCatalog
+from neutronclient.v2_0 import client as NeutronClient
 from novaclient.client import Client
 from swiftclient.client import Connection
 
@@ -83,11 +84,11 @@ def guest_client(context, id, manager=None):
     return clazz(context, id)
 
 
-def nova_client(context, region_name=None):
+def nova_client(context, region_name=None, password=None):
     if CONF.nova_compute_url:
         url = '%(nova_url)s%(tenant)s' % {
             'nova_url': normalize_url(CONF.nova_compute_url),
-            'tenant': context.tenant}
+            'tenant': context.project_id}
     else:
         url = get_endpoint(context.service_catalog,
                            service_type=CONF.nova_compute_service_type,
@@ -96,13 +97,16 @@ def nova_client(context, region_name=None):
 
     client = Client(CONF.nova_client_version,
                     username=context.user,
-                    bypass_url=url,
-                    tenant_id=context.tenant,
+                    password=password,
+                    endpoint_override=url,
+                    project_id=context.project_id,
                     project_domain_name=context.project_domain_name,
+                    user_domain_name=context.user_domain_name,
                     auth_url=CONF.trove_auth_url,
-                    auth_token=context.auth_token)
+                    auth_token=context.auth_token,
+                    insecure=CONF.nova_api_insecure)
     client.client.auth_token = context.auth_token
-    client.client.management_url = url
+    client.client.endpoint_override = url
     return client
 
 
@@ -111,7 +115,7 @@ def create_admin_nova_client(context):
     Creates client that uses trove admin credentials
     :return: a client for nova for the trove admin
     """
-    client = create_nova_client(context)
+    client = create_nova_client(context, password=CONF.nova_proxy_admin_pass)
     return client
 
 
@@ -128,7 +132,8 @@ def cinder_client(context, region_name=None):
 
     client = CinderClient.Client(context.user, context.auth_token,
                                  project_id=context.tenant,
-                                 auth_url=CONF.trove_auth_url)
+                                 auth_url=CONF.trove_auth_url,
+                                 insecure=CONF.cinder_api_insecure)
     client.client.auth_token = context.auth_token
     client.client.management_url = url
     return client
@@ -148,12 +153,12 @@ def swift_client(context, region_name=None):
     client = Connection(preauthurl=url,
                         preauthtoken=context.auth_token,
                         tenant_name=context.tenant,
-                        snet=CONF.backup_use_snet)
+                        snet=CONF.backup_use_snet,
+                        insecure=CONF.swift_api_insecure)
     return client
 
 
 def neutron_client(context, region_name=None):
-    from neutronclient.v2_0 import client as NeutronClient
     if CONF.neutron_url:
         # neutron endpoint url / publicURL does not include tenant segment
         url = CONF.neutron_url
@@ -164,13 +169,30 @@ def neutron_client(context, region_name=None):
                            endpoint_type=CONF.neutron_endpoint_type)
 
     client = NeutronClient.Client(token=context.auth_token,
-                                  endpoint_url=url)
+                                  endpoint_url=url,
+                                  insecure=CONF.neutron_api_insecure)
     return client
 
 
-create_dns_client = import_class(CONF.remote_dns_client)
-create_guest_client = import_class(CONF.remote_guest_client)
-create_nova_client = import_class(CONF.remote_nova_client)
-create_swift_client = import_class(CONF.remote_swift_client)
-create_cinder_client = import_class(CONF.remote_cinder_client)
-create_neutron_client = import_class(CONF.remote_neutron_client)
+def create_dns_client(*arg, **kwargs):
+    return import_class(CONF.remote_dns_client)(*arg, **kwargs)
+
+
+def create_guest_client(*arg, **kwargs):
+    return import_class(CONF.remote_guest_client)(*arg, **kwargs)
+
+
+def create_nova_client(*arg, **kwargs):
+    return import_class(CONF.remote_nova_client)(*arg, **kwargs)
+
+
+def create_swift_client(*arg, **kwargs):
+    return import_class(CONF.remote_swift_client)(*arg, **kwargs)
+
+
+def create_cinder_client(*arg, **kwargs):
+    return import_class(CONF.remote_cinder_client)(*arg, **kwargs)
+
+
+def create_neutron_client(*arg, **kwargs):
+    return import_class(CONF.remote_neutron_client)(*arg, **kwargs)
