@@ -87,9 +87,12 @@ class MongoDbCluster(models.Cluster):
         deltas = {'instances': delta_instances, 'volumes': req_volume_size}
 
         check_quotas(context.tenant, deltas)
+        # Checking networks are same for the cluster
+        models.validate_instance_nics(context, instances)
 
         flavor_id = instances[0]['flavor_id']
         volume_size = instances[0].get('volume_size', None)
+        volume_type = instances[0].get('volume_type', None)
 
         nics = [instance.get('nics', None) for instance in instances]
 
@@ -135,6 +138,7 @@ class MongoDbCluster(models.Cluster):
                                         nics=nics[i],
                                         configuration_id=None,
                                         cluster_config=member_config,
+                                        volume_type=volume_type,
                                         modules=instances[i].get('modules'),
                                         locality=locality,
                                         region_name=regions[i])
@@ -151,8 +155,10 @@ class MongoDbCluster(models.Cluster):
                                         nics=None,
                                         configuration_id=None,
                                         cluster_config=configsvr_config,
+                                        volume_type=volume_type,
                                         locality=locality,
-                                        region_name=regions[i])
+                                        region_name=regions[i % num_instances]
+                                        )
 
         for i in range(1, num_mongos + 1):
             instance_name = "%s-%s-%s" % (name, "mongos", str(i))
@@ -166,8 +172,10 @@ class MongoDbCluster(models.Cluster):
                                         nics=None,
                                         configuration_id=None,
                                         cluster_config=mongos_config,
+                                        volume_type=volume_type,
                                         locality=locality,
-                                        region_name=regions[i])
+                                        region_name=regions[i % num_instances]
+                                        )
 
         task_api.load(context, datastore_version.manager).create_cluster(
             db_info.id)
@@ -198,8 +206,8 @@ class MongoDbCluster(models.Cluster):
                                                          required=True))
         volume_size = int(_check_option('volume', required=True)['size'])
         instance_type = _check_option('type', required=True,
-                                      valid_values=['replica',
-                                                    'query_router'])
+                                      valid_values=[u'replica',
+                                                    u'query_router'])
         name = _check_option('name')
         related_to = _check_option('related_to')
         nics = _check_option('nics')
@@ -242,20 +250,24 @@ class MongoDbCluster(models.Cluster):
 
         if self.db_info.task_status != ClusterTasks.NONE:
             current_task = self.db_info.task_status.name
-            msg = _("This action cannot be performed on the cluster while "
-                    "the current cluster task is '%s'.") % current_task
-            LOG.error(msg)
-            raise exception.UnprocessableEntity(msg)
+            log_fmt = ("This action cannot be performed on the cluster while "
+                       "the current cluster task is '%s'.")
+            exc_fmt = _("This action cannot be performed on the cluster while "
+                        "the current cluster task is '%s'.")
+            LOG.error(log_fmt, current_task)
+            raise exception.UnprocessableEntity(exc_fmt % current_task)
 
         db_insts = inst_models.DBInstance.find_all(cluster_id=self.id,
+                                                   deleted=False,
                                                    type='member').all()
         num_unique_shards = len(set([db_inst.shard_id for db_inst
                                      in db_insts]))
         if num_unique_shards == 0:
-            msg = _("This action cannot be performed on the cluster as no "
-                    "reference shard exists.")
-            LOG.error(msg)
-            raise exception.UnprocessableEntity(msg)
+            LOG.error("This action cannot be performed on the cluster as no "
+                      "reference shard exists.")
+            raise exception.UnprocessableEntity(
+                _("This action cannot be performed on the cluster as no "
+                  "reference shard exists."))
 
         arbitrary_shard_id = db_insts[0].shard_id
         members_in_shard = [db_inst for db_inst in db_insts
@@ -452,10 +464,12 @@ class MongoDbCluster(models.Cluster):
         """Get information about the cluster's current state."""
         if self.db_info.task_status != ClusterTasks.NONE:
             current_task = self.db_info.task_status.name
-            msg = _("This action cannot be performed on the cluster while "
-                    "the current cluster task is '%s'.") % current_task
-            LOG.error(msg)
-            raise exception.UnprocessableEntity(msg)
+            log_fmt = ("This action cannot be performed on the cluster while "
+                       "the current cluster task is '%s'.")
+            exc_fmt = _("This action cannot be performed on the cluster while "
+                        "the current cluster task is '%s'.")
+            LOG.error(log_fmt, current_task)
+            raise exception.UnprocessableEntity(exc_fmt % current_task)
 
         def _instances_of_type(instance_type):
             return [db_inst for db_inst in self.db_instances
@@ -477,7 +491,7 @@ class MongoDbCluster(models.Cluster):
         query_routers = []
         for item in instances:
             if item['instance_type'] == 'replica':
-                replica_requirements = ['related_to', 'name']
+                replica_requirements = ['name']
                 if not all(key in item for key in replica_requirements):
                     raise exception.TroveError(
                         _('Replica instance does not have required field(s) '
