@@ -61,6 +61,10 @@ class RedisCluster(models.Cluster):
         total_volume_allocation = models.get_required_volume_size(
             instances, volume_enabled)
 
+        models.assert_homogeneous_cluster(instances)
+
+        models.validate_instance_nics(context, instances)
+
         name_index = 1
         for instance in instances:
             if not instance.get('name'):
@@ -88,6 +92,8 @@ class RedisCluster(models.Cluster):
                                             cluster_config={
                                                 "id": db_info.id,
                                                 "instance_type": "member"},
+                                            volume_type=instance.get(
+                                                'volume_type', None),
                                             modules=instance.get('modules'),
                                             locality=locality,
                                             region_name=instance.get(
