@@ -20,13 +20,13 @@ from trove.common.i18n import _
 from trove.common.strategies.cluster import base
 from trove.instance.models import DBInstance
 from trove.instance.models import Instance
+from trove.instance import tasks as inst_tasks
 from trove.taskmanager import api as task_api
 import trove.taskmanager.models as task_models
 
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
-USAGE_SLEEP_TIME = CONF.usage_sleep_time  # seconds.
 
 
 class RedisTaskManagerStrategy(base.BaseTaskManagerStrategy):
@@ -85,7 +85,7 @@ class RedisClusterTasks(task_models.ClusterTasks):
                 for guest in guests:
                     guest.cluster_complete()
             except Exception:
-                LOG.exception(_("Error creating cluster."))
+                LOG.exception("Error creating cluster.")
                 self.update_statuses_on_failure(cluster_id)
 
         timeout = Timeout(CONF.cluster_usage_timeout)
@@ -95,7 +95,7 @@ class RedisClusterTasks(task_models.ClusterTasks):
         except Timeout as t:
             if t is not timeout:
                 raise  # not my timeout
-            LOG.exception(_("Timeout for building cluster."))
+            LOG.exception("Timeout for building cluster.")
             self.update_statuses_on_failure(cluster_id)
         finally:
             timeout.cancel()
@@ -107,7 +107,8 @@ class RedisClusterTasks(task_models.ClusterTasks):
 
         def _grow_cluster():
 
-            db_instances = DBInstance.find_all(cluster_id=cluster_id).all()
+            db_instances = DBInstance.find_all(cluster_id=cluster_id,
+                                               deleted=False).all()
             cluster_head = next(Instance.load(context, db_inst.id)
                                 for db_inst in db_instances
                                 if db_inst.id not in new_instance_ids)
@@ -141,11 +142,13 @@ class RedisClusterTasks(task_models.ClusterTasks):
         except Timeout as t:
             if t is not timeout:
                 raise  # not my timeout
-            LOG.exception(_("Timeout for growing cluster."))
-            self.update_statuses_on_failure(cluster_id)
+            LOG.exception("Timeout for growing cluster.")
+            self.update_statuses_on_failure(
+                cluster_id, status=inst_tasks.InstanceTasks.GROWING_ERROR)
         except Exception:
-            LOG.exception(_("Error growing cluster %s."), cluster_id)
-            self.update_statuses_on_failure(cluster_id)
+            LOG.exception("Error growing cluster %s.", cluster_id)
+            self.update_statuses_on_failure(
+                cluster_id, status=inst_tasks.InstanceTasks.GROWING_ERROR)
         finally:
             timeout.cancel()
 
