@@ -74,7 +74,8 @@ class VerticaCluster(models.Cluster):
         vertica_conf = CONF.get(datastore_version.manager)
         num_instances = len(instances)
 
-        existing = inst_models.DBInstance.find_all(cluster_id=db_info.id).all()
+        existing = inst_models.DBInstance.find_all(cluster_id=db_info.id,
+                                                   deleted=False).all()
         num_existing = len(existing)
 
         # Matching number of instances with configured cluster_member_count
@@ -91,12 +92,15 @@ class VerticaCluster(models.Cluster):
             instances, vertica_conf.volume_support)
         models.assert_homogeneous_cluster(instances)
 
+        models.validate_instance_nics(context, instances)
+
         deltas = {'instances': num_instances, 'volumes': req_volume_size}
 
         check_quotas(context.tenant, deltas)
 
         flavor_id = instances[0]['flavor_id']
         volume_size = instances[0].get('volume_size', None)
+        volume_type = instances[0].get('volume_type', None)
 
         nics = [instance.get('nics', None) for instance in instances]
 
@@ -122,6 +126,7 @@ class VerticaCluster(models.Cluster):
                     datastore_version, volume_size, None,
                     nics=nics[i], availability_zone=azs[i],
                     configuration_id=None, cluster_config=member_config,
+                    volume_type=volume_type,
                     modules=instances[i].get('modules'), locality=locality,
                     region_name=regions[i])
             )
