@@ -26,6 +26,8 @@ def map(engine, models):
         return
 
     orm.mapper(models['instance'], Table('instances', meta, autoload=True))
+    orm.mapper(models['instance_faults'],
+               Table('instance_faults', meta, autoload=True))
     orm.mapper(models['root_enabled_history'],
                Table('root_enabled_history', meta, autoload=True))
     orm.mapper(models['datastore'],
