@@ -27,14 +27,3 @@ def upgrade(migrate_engine):
     instances = Table('instances', meta, autoload=True)
     instances.create_column(Column('tenant_id', String(36), nullable=True))
     instances.create_column(Column('server_status', String(64)))
-
-
-def downgrade(migrate_engine):
-    meta = MetaData()
-    meta.bind = migrate_engine
-
-    # drop column:
-    instances = Table('instances', meta, autoload=True)
-
-    instances.drop_column('tenant_id')
-    instances.drop_column('server_status')
