@@ -26,7 +26,6 @@ from trove.cluster.models import DBCluster
 from trove.common import cfg
 from trove.common import exception
 from trove.common.i18n import _
-from trove.common.i18n import _LI
 from trove.common import policy
 from trove.common import wsgi
 from trove.datastore import models as datastore_models
@@ -93,8 +92,8 @@ class DefaultRootController(BaseDatastoreRootController):
         if is_cluster:
             raise exception.ClusterOperationNotSupported(
                 operation='show_root')
-        LOG.info(_LI("Getting root enabled for instance '%s'."), instance_id)
-        LOG.info(_LI("req : '%s'\n\n"), req)
+        LOG.info("Getting root enabled for instance '%s'.", instance_id)
+        LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         is_root_enabled = models.Root.load(context, instance_id)
         return wsgi.Result(views.RootEnabledView(is_root_enabled).data(), 200)
@@ -103,8 +102,8 @@ class DefaultRootController(BaseDatastoreRootController):
         if is_cluster:
             raise exception.ClusterOperationNotSupported(
                 operation='enable_root')
-        LOG.info(_LI("Enabling root for instance '%s'."), instance_id)
-        LOG.info(_LI("req : '%s'\n\n"), req)
+        LOG.info("Enabling root for instance '%s'.", instance_id)
+        LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         user_name = context.user
         password = DefaultRootController._get_password_from_body(body)
@@ -116,13 +115,13 @@ class DefaultRootController(BaseDatastoreRootController):
         if is_cluster:
             raise exception.ClusterOperationNotSupported(
                 operation='disable_root')
-        LOG.info(_LI("Disabling root for instance '%s'."), instance_id)
-        LOG.info(_LI("req : '%s'\n\n"), req)
+        LOG.info("Disabling root for instance '%s'.", instance_id)
+        LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         try:
             found_user = self._find_root_user(context, instance_id)
         except (ValueError, AttributeError) as e:
-            raise exception.BadRequest(msg=str(e))
+            raise exception.BadRequest(message=str(e))
         if not found_user:
             raise exception.UserNotFound(uuid="root")
         models.Root.delete(context, instance_id)
@@ -139,8 +138,8 @@ class ClusterRootController(DefaultRootController):
             return self.instance_root_index(req, tenant_id, instance_id)
 
     def instance_root_index(self, req, tenant_id, instance_id):
-        LOG.info(_LI("Getting root enabled for instance '%s'."), instance_id)
-        LOG.info(_LI("req : '%s'\n\n"), req)
+        LOG.info("Getting root enabled for instance '%s'.", instance_id)
+        LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         try:
             is_root_enabled = models.ClusterRoot.load(context, instance_id)
@@ -150,7 +149,7 @@ class ClusterRootController(DefaultRootController):
         return wsgi.Result(views.RootEnabledView(is_root_enabled).data(), 200)
 
     def cluster_root_index(self, req, tenant_id, cluster_id):
-        LOG.info(_LI("Getting root enabled for cluster '%s'."), cluster_id)
+        LOG.info("Getting root enabled for cluster '%s'.", cluster_id)
         single_instance_id, cluster_instances = self._get_cluster_instance_id(
             tenant_id, cluster_id)
         return self.instance_root_index(req, tenant_id, single_instance_id)
@@ -173,8 +172,8 @@ class ClusterRootController(DefaultRootController):
 
     def instance_root_create(self, req, body, instance_id,
                              cluster_instances=None):
-        LOG.info(_LI("Enabling root for instance '%s'."), instance_id)
-        LOG.info(_LI("req : '%s'\n\n"), req)
+        LOG.info("Enabling root for instance '%s'.", instance_id)
+        LOG.info("req : '%s'\n\n", req)
         context = req.environ[wsgi.CONTEXT_KEY]
         user_name = context.user
         password = ClusterRootController._get_password_from_body(body)
@@ -183,14 +182,16 @@ class ClusterRootController(DefaultRootController):
         return wsgi.Result(views.RootCreatedView(root).data(), 200)
 
     def cluster_root_create(self, req, body, tenant_id, cluster_id):
-        LOG.info(_LI("Enabling root for cluster '%s'."), cluster_id)
+        LOG.info("Enabling root for cluster '%s'.", cluster_id)
         single_instance_id, cluster_instances = self._get_cluster_instance_id(
             tenant_id, cluster_id)
         return self.instance_root_create(req, body, single_instance_id,
                                          cluster_instances)
 
     def _find_cluster_node_ids(self, tenant_id, cluster_id):
-        args = {'tenant_id': tenant_id, 'cluster_id': cluster_id}
+        args = {'tenant_id': tenant_id,
+                'cluster_id': cluster_id,
+                'deleted': False}
         cluster_instances = DBInstance.find_all(**args).all()
         return [db_instance.id for db_instance in cluster_instances]
 
