@@ -16,11 +16,10 @@
 from glanceclient import exc as glance_exceptions
 from oslo_log import log as logging
 
-from trove.common import apischema as apischema
+from trove.common import apischema
 from trove.common.auth import admin_context
 from trove.common import exception
 from trove.common import glance_remote
-from trove.common.i18n import _
 from trove.common import utils
 from trove.common import wsgi
 from trove.datastore import models
@@ -48,8 +47,8 @@ class DatastoreVersionController(wsgi.Controller):
         active = body['version']['active']
         default = body['version']['default']
 
-        LOG.info(_("Tenant: '%(tenant)s' is adding the datastore "
-                   "version: '%(version)s' to datastore: '%(datastore)s'"),
+        LOG.info("Tenant: '%(tenant)s' is adding the datastore "
+                 "version: '%(version)s' to datastore: '%(datastore)s'",
                  {'tenant': tenant_id, 'version': version_name,
                   'datastore': datastore_name})
 
@@ -63,7 +62,7 @@ class DatastoreVersionController(wsgi.Controller):
             datastore = models.Datastore.load(datastore_name)
         except exception.DatastoreNotFound:
             # Create the datastore if datastore_name does not exists.
-            LOG.info(_("Creating datastore %s"), datastore_name)
+            LOG.info("Creating datastore %s", datastore_name)
             datastore = models.DBDatastore()
             datastore.id = utils.generate_uuid()
             datastore.name = datastore_name
@@ -106,8 +105,8 @@ class DatastoreVersionController(wsgi.Controller):
         context = req.environ[wsgi.CONTEXT_KEY]
         datastore_version = models.DatastoreVersion.load_by_uuid(id)
 
-        LOG.info(_("Tenant: '%(tenant)s' is updating the datastore "
-                   "version: '%(version)s' for datastore: '%(datastore)s'"),
+        LOG.info("Tenant: '%(tenant)s' is updating the datastore "
+                 "version: '%(version)s' for datastore: '%(datastore)s'",
                  {'tenant': tenant_id, 'version': datastore_version.name,
                   'datastore': datastore_version.datastore_name})
 
@@ -144,8 +143,8 @@ class DatastoreVersionController(wsgi.Controller):
         datastore_version = models.DatastoreVersion.load_by_uuid(id)
         datastore = models.Datastore.load(datastore_version.datastore_id)
 
-        LOG.info(_("Tenant: '%(tenant)s' is removing the datastore "
-                   "version: '%(version)s' for datastore: '%(datastore)s'"),
+        LOG.info("Tenant: '%(tenant)s' is removing the datastore "
+                 "version: '%(version)s' for datastore: '%(datastore)s'",
                  {'tenant': tenant_id, 'version': datastore_version.name,
                   'datastore': datastore.name})
 
