@@ -13,15 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-
 from trove.common import extensions
 from trove.extensions.account import service
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Account(extensions.ExtensionDescriptor):
 
     def get_name(self):
