@@ -20,11 +20,12 @@ from redis.exceptions import BusyLoadingError, ConnectionError
 from oslo_log import log as logging
 
 from trove.common import cfg
+from trove.common.db.redis.models import RedisRootUser
 from trove.common import exception
 from trove.common.i18n import _
 from trove.common import instance as rd_instance
 from trove.common.stream_codecs import PropertiesCodec, StringConverter
-from trove.common import utils as utils
+from trove.common import utils
 from trove.guestagent.common.configuration import ConfigurationManager
 from trove.guestagent.common.configuration import OneFileOverrideStrategy
 from trove.guestagent.common import guestagent_utils
@@ -37,6 +38,7 @@ LOG = logging.getLogger(__name__)
 TIME_OUT = 1200
 CONF = cfg.CONF
 CLUSTER_CFG = 'clustering'
+SYS_OVERRIDES_AUTH = 'auth_password'
 packager = pkg.Package()
 
 
@@ -61,7 +63,7 @@ class RedisAppStatus(service.BaseDbStatus):
         except BusyLoadingError:
             return rd_instance.ServiceStatuses.BLOCKED
         except Exception:
-            LOG.exception(_("Error getting Redis status."))
+            LOG.exception("Error getting Redis status.")
 
         return rd_instance.ServiceStatuses.CRASHED
 
@@ -107,18 +109,25 @@ class RedisApp(object):
     def _build_admin_client(self):
         password = self.get_configuration_property('requirepass')
         socket = self.get_configuration_property('unixsocket')
+        cmd = self.get_config_command_name()
 
-        return RedisAdmin(password=password, unix_socket_path=socket)
+        return RedisAdmin(password=password, unix_socket_path=socket,
+                          config_cmd=cmd)
+
+    def _refresh_admin_client(self):
+        self.admin = self._build_admin_client()
+        self.status.set_client(self.admin)
+        return self.admin
 
     def install_if_needed(self, packages):
         """
         Install redis if needed do nothing if it is already installed.
         """
-        LOG.info(_('Preparing Guest as Redis Server.'))
+        LOG.info('Preparing Guest as Redis Server.')
         if not packager.pkg_is_installed(packages):
-            LOG.info(_('Installing Redis.'))
+            LOG.info('Installing Redis.')
             self._install_redis(packages)
-        LOG.info(_('Redis installed completely.'))
+        LOG.info('Redis installed completely.')
 
     def _install_redis(self, packages):
         """
@@ -144,6 +153,10 @@ class RedisApp(object):
     def update_overrides(self, context, overrides, remove=False):
         if overrides:
             self.configuration_manager.apply_user_override(overrides)
+            # apply requirepass at runtime
+            if 'requirepass' in overrides:
+                self.admin.config_set('requirepass', overrides['requirepass'])
+                self._refresh_admin_client()
 
     def apply_overrides(self, client, overrides):
         """Use the 'CONFIG SET' command to apply configuration at runtime.
@@ -165,7 +178,9 @@ class RedisApp(object):
         for prop_name, prop_args in overrides.items():
             args_string = self._join_lists(
                 self._value_converter.to_strings(prop_args), ' ')
-            client.config_set(prop_name, args_string)
+            # requirepass applied at runtime during update_overrides
+            if prop_name != "requirepass":
+                client.config_set(prop_name, args_string)
 
     def _join_lists(self, items, sep):
         """Join list items (including items from sub-lists) into a string.
@@ -188,12 +203,12 @@ class RedisApp(object):
         pass
 
     def start_db_with_conf_changes(self, config_contents):
-        LOG.info(_('Starting redis with conf changes.'))
+        LOG.info('Starting redis with conf changes.')
         if self.status.is_running:
             format = 'Cannot start_db_with_conf_changes because status is %s.'
             LOG.debug(format, self.status)
             raise RuntimeError(format % self.status)
-        LOG.info(_("Initiating config."))
+        LOG.info("Initiating config.")
         self.configuration_manager.save_configuration(config_contents)
         # The configuration template has to be updated with
         # guestagent-controlled settings.
@@ -224,9 +239,10 @@ class RedisApp(object):
         """Get current name of the 'CONFIG' command.
         """
         renamed_cmds = self.configuration_manager.get_value('rename-command')
-        for name_pair in renamed_cmds:
-            if name_pair[0] == 'CONFIG':
-                return name_pair[1]
+        if renamed_cmds:
+            for name_pair in renamed_cmds:
+                if name_pair[0] == 'CONFIG':
+                    return name_pair[1]
 
         return None
 
@@ -334,7 +350,7 @@ class RedisApp(object):
             utils.execute_with_timeout('redis-cli', 'cluster', 'meet',
                                        ip, port)
         except exception.ProcessExecutionError:
-            LOG.exception(_('Error joining node to cluster at %s.'), ip)
+            LOG.exception('Error joining node to cluster at %s.', ip)
             raise
 
     def cluster_addslots(self, first_slot, last_slot):
@@ -351,8 +367,8 @@ class RedisApp(object):
                                        % out)
                 del slots[0:group_size]
         except exception.ProcessExecutionError:
-            LOG.exception(_('Error adding slots %(first_slot)s-%(last_slot)s'
-                            ' to cluster.'),
+            LOG.exception('Error adding slots %(first_slot)s-%(last_slot)s'
+                          ' to cluster.',
                           {'first_slot': first_slot, 'last_slot': last_slot})
             raise
 
@@ -362,7 +378,7 @@ class RedisApp(object):
                                                 'cluster', 'nodes')
             return [line.split(' ') for line in out.splitlines()]
         except exception.ProcessExecutionError:
-            LOG.exception(_('Error getting node info.'))
+            LOG.exception('Error getting node info.')
             raise
 
     def _get_node_details(self):
@@ -384,7 +400,7 @@ class RedisApp(object):
                                                   'cluster', 'slots')
             return node_id if my_ip not in slots else None
         except exception.ProcessExecutionError:
-            LOG.exception(_('Error validating node to for removal.'))
+            LOG.exception('Error validating node to for removal.')
             raise
 
     def remove_nodes(self, node_ids):
@@ -393,7 +409,32 @@ class RedisApp(object):
                 utils.execute_with_timeout('redis-cli', 'cluster',
                                            'forget', node_id)
         except exception.ProcessExecutionError:
-            LOG.exception(_('Error removing node from cluster.'))
+            LOG.exception('Error removing node from cluster.')
+            raise
+
+    def enable_root(self, password=None):
+        if not password:
+            password = utils.generate_random_password()
+        redis_password = RedisRootUser(password=password)
+        try:
+            self.configuration_manager.apply_system_override(
+                {'requirepass': password, 'masterauth': password},
+                change_id=SYS_OVERRIDES_AUTH)
+            self.apply_overrides(
+                self.admin, {'requirepass': password, 'masterauth': password})
+        except exception.TroveError:
+            LOG.exception('Error enabling authentication for instance.')
+            raise
+        return redis_password.serialize()
+
+    def disable_root(self):
+        try:
+            self.configuration_manager.remove_system_override(
+                change_id=SYS_OVERRIDES_AUTH)
+            self.apply_overrides(self.admin,
+                                 {'requirepass': '', 'masterauth': ''})
+        except exception.TroveError:
+            LOG.exception('Error disabling authentication for instance.')
             raise
 
 
@@ -403,10 +444,10 @@ class RedisAdmin(object):
 
     DEFAULT_CONFIG_CMD = 'CONFIG'
 
-    def __init__(self, password=None, unix_socket_path=None):
+    def __init__(self, password=None, unix_socket_path=None, config_cmd=None):
         self.__client = redis.StrictRedis(
             password=password, unix_socket_path=unix_socket_path)
-        self.__config_cmd_name = self.DEFAULT_CONFIG_CMD
+        self.__config_cmd_name = config_cmd or self.DEFAULT_CONFIG_CMD
 
     def set_config_command_name(self, name):
         """Set name of the 'CONFIG' command or None for default.
@@ -432,7 +473,7 @@ class RedisAdmin(object):
             # If an auto-save is in progress just use it, since it must have
             # just happened
             if "Background save already in progress" in str(re):
-                LOG.info(_("Waiting for existing background save to finish"))
+                LOG.info("Waiting for existing background save to finish")
             else:
                 raise
         if save_ok:
@@ -497,7 +538,7 @@ class RedisAdmin(object):
                 LOG.debug("Found '%(value)s' for field %(key)s.",
                           {'value': current_value, 'key': key})
             else:
-                LOG.error(_('Output from Redis command: %s'), redis_info)
+                LOG.error('Output from Redis command: %s', redis_info)
                 raise RuntimeError(_("Field %(field)s not found "
                                      "(Section: '%(sec)s').") %
                                    ({'field': key, 'sec': section}))
