@@ -25,7 +25,6 @@ from trove.common import utils
 from trove.guestagent.common import operating_system
 from trove.guestagent.datastore.experimental.couchbase import service
 from trove.guestagent.datastore.experimental.couchbase import system
-from trove.guestagent import dbaas
 from trove.guestagent.strategies.restore import base
 
 
@@ -45,9 +44,9 @@ class CbBackup(base.RestoreRunner):
     def pre_restore(self):
         try:
             operating_system.remove(system.COUCHBASE_DUMP_DIR, force=True)
-        except exception.ProcessExecutionError as p:
-            LOG.error(p)
-            raise p
+        except exception.ProcessExecutionError:
+            LOG.exception("Error during pre-restore phase.")
+            raise
 
     def post_restore(self):
         try:
@@ -76,7 +75,7 @@ class CbBackup(base.RestoreRunner):
                     bucket_type = d[i]["bucketType"]
                     if bucket_type == "membase":
                         bucket_type = "couchbase"
-                    ram = int(dbaas.to_mb(d[i]["quota"]["ram"]))
+                    ram = int(utils.to_mb(d[i]["quota"]["ram"]))
                     auth_type = d[i]["authType"]
                     password = d[i]["saslPassword"]
                     port = d[i]["proxyPort"]
@@ -187,12 +186,11 @@ class CbBackup(base.RestoreRunner):
                         utils.execute_with_timeout(restore_cmd,
                                                    shell=True,
                                                    timeout=300)
-                    except exception.ProcessExecutionError as p:
+                    except exception.ProcessExecutionError:
                         # cbrestore fails or hangs at times:
                         # http://www.couchbase.com/issues/browse/MB-10832
                         # Retrying typically works
-                        LOG.error(p)
-                        LOG.error(_("cbrestore failed. Retrying..."))
+                        LOG.exception("cbrestore failed. Retrying...")
                         utils.execute_with_timeout(restore_cmd,
                                                    shell=True,
                                                    timeout=300)
