@@ -26,7 +26,6 @@ from trove.common import exception
 from trove.common.utils import generate_uuid
 from trove.common.utils import poll_until
 from trove import tests
-from trove.tests.api.instances import assert_unprocessable
 from trove.tests.api.instances import instance_info
 from trove.tests.api.instances import TIMEOUT_INSTANCE_CREATE
 from trove.tests.api.instances import TIMEOUT_INSTANCE_DELETE
@@ -56,30 +55,6 @@ backup_count_for_instance_prior_to_create = 0
       groups=[GROUP, tests.INSTANCES])
 class CreateBackups(object):
 
-    @test
-    def test_backup_create_instance_invalid(self):
-        """Test create backup with unknown instance."""
-        invalid_inst_id = 'invalid-inst-id'
-        try:
-            instance_info.dbaas.backups.create(BACKUP_NAME, invalid_inst_id,
-                                               BACKUP_DESC)
-        except exceptions.BadRequest as e:
-            resp, body = instance_info.dbaas.client.last_response
-            assert_equal(resp.status, 400)
-            assert_equal(e.message,
-                         "Validation error: "
-                         "backup['instance'] u'%s' does not match "
-                         "'^([0-9a-fA-F]){8}-([0-9a-fA-F]){4}-"
-                         "([0-9a-fA-F]){4}-([0-9a-fA-F]){4}-"
-                         "([0-9a-fA-F]){12}$'" %
-                         invalid_inst_id)
-
-    @test
-    def test_backup_create_instance_not_found(self):
-        """Test create backup with unknown instance."""
-        assert_raises(exceptions.NotFound, instance_info.dbaas.backups.create,
-                      BACKUP_NAME, generate_uuid(), BACKUP_DESC)
-
     @test
     def test_backup_create_instance(self):
         """Test create backup for a given instance."""
@@ -89,6 +64,9 @@ class CreateBackups(object):
         global backup_count_for_instance_prior_to_create
         backup_count_for_instance_prior_to_create = len(
             instance_info.dbaas.instances.backups(instance_info.id))
+        datastore_version = instance_info.dbaas.datastore_versions.get(
+            instance_info.dbaas_datastore,
+            instance_info.dbaas_datastore_version)
 
         result = instance_info.dbaas.backups.create(BACKUP_NAME,
                                                     instance_info.id,
@@ -101,10 +79,6 @@ class CreateBackups(object):
         assert_equal('NEW', result.status)
         instance = instance_info.dbaas.instances.get(instance_info.id)
 
-        datastore_version = instance_info.dbaas.datastore_versions.get(
-            instance_info.dbaas_datastore,
-            instance_info.dbaas_datastore_version)
-
         assert_equal('BACKUP', instance.status)
         assert_equal(instance_info.dbaas_datastore,
                      result.datastore['type'])
@@ -113,38 +87,7 @@ class CreateBackups(object):
         assert_equal(datastore_version.id, result.datastore['version_id'])
 
 
-@test(runs_after=[CreateBackups],
-      groups=[GROUP, tests.INSTANCES])
-class AfterBackupCreation(object):
-
-    @test
-    def test_restore_instance_from_not_completed_backup(self):
-        assert_raises(exceptions.Conflict,
-                      RestoreUsingBackup._restore, backup_info.id)
-        assert_equal(409, instance_info.dbaas.last_http_code)
-
-    @test
-    def test_instance_action_right_after_backup_create(self):
-        """Test any instance action while backup is running."""
-        assert_unprocessable(instance_info.dbaas.instances.resize_instance,
-                             instance_info.id, 1)
-
-    @test
-    def test_backup_create_another_backup_running(self):
-        """Test create backup when another backup is running."""
-        assert_unprocessable(instance_info.dbaas.backups.create,
-                             'backup_test2', instance_info.id,
-                             'test description2')
-
-    @test
-    def test_backup_delete_still_running(self):
-        """Test delete backup when it is running."""
-        result = instance_info.dbaas.backups.list()
-        backup = result[0]
-        assert_unprocessable(instance_info.dbaas.backups.delete, backup.id)
-
-
-class BackupRestoreMixin():
+class BackupRestoreMixin(object):
 
     def verify_backup(self, backup_id):
         def result_is_active():
@@ -198,7 +141,7 @@ class BackupRestoreMixin():
                    time_out=TIMEOUT_INSTANCE_CREATE)
 
 
-@test(runs_after=[AfterBackupCreation],
+@test(runs_after=[CreateBackups],
       groups=[GROUP, tests.INSTANCES])
 class WaitForBackupCreateToFinish(BackupRestoreMixin):
     """
@@ -340,6 +283,7 @@ class RestoreUsingBackup(object):
             instance_info.volume,
             datastore=instance_info.dbaas_datastore,
             datastore_version=instance_info.dbaas_datastore_version,
+            nics=instance_info.nics,
             restorePoint=restorePoint)
         assert_equal(200, instance_info.dbaas.last_http_code)
         assert_equal("BUILD", result.status)
@@ -532,6 +476,7 @@ class FakeTestHugeBackupOnSmallInstance(BackupRestoreMixin):
                       datastore=instance_info.dbaas_datastore,
                       datastore_version=(instance_info.
                                          dbaas_datastore_version),
+                      nics=instance_info.nics,
                       restorePoint={"backupRef": self.new_backup.id})
         assert_equal(403, instance_info.dbaas.last_http_code)
 
@@ -549,6 +494,7 @@ class FakeTestHugeBackupOnSmallInstance(BackupRestoreMixin):
                       datastore=instance_info.dbaas_datastore,
                       datastore_version=(instance_info.
                                          dbaas_datastore_version),
+                      nics=instance_info.nics,
                       restorePoint={"backupRef": self.new_backup.id})
 
         assert_equal(403, instance_info.dbaas.last_http_code)
