@@ -16,6 +16,7 @@
 
 from datetime import datetime
 import json
+import netaddr
 from time import sleep
 import uuid
 
@@ -24,10 +25,12 @@ from proboscis.asserts import assert_equal
 from proboscis.asserts import assert_not_equal
 from proboscis.asserts import assert_raises
 from proboscis.asserts import assert_true
+from proboscis.asserts import fail
 from proboscis import before_class
 from proboscis.decorators import time_out
 from proboscis import SkipTest
 from proboscis import test
+import six
 from troveclient.compat import exceptions
 
 from trove.common.utils import poll_until
@@ -83,7 +86,11 @@ def _execute_query(host, user_name, password, query):
 
 def _get_address(instance_id):
     result = instance_info.dbaas_admin.mgmt.instances.show(instance_id)
-    return result.ip[0]
+    try:
+        return next(str(ip) for ip in result.ip
+                    if netaddr.valid_ipv4(ip))
+    except StopIteration:
+        fail("No IPV4 ip found")
 
 
 def _test_configuration_is_applied_to_instance(instance, configuration_id):
@@ -166,8 +173,8 @@ class ConfigurationsTestBase(object):
         """Returns the expected test configurations for the default datastore
         defined in the Test Config as dbaas_datastore.
         """
-        default_datatstore = CONFIG.get('dbaas_datastore', None)
-        datastore_test_configs = CONFIG.get(default_datatstore, {})
+        default_datastore = CONFIG.get('dbaas_datastore', None)
+        datastore_test_configs = CONFIG.get(default_datastore, {})
         return datastore_test_configs.get("configurations", {})
 
 
@@ -227,12 +234,12 @@ class CreateConfigurations(ConfigurationsTestBase):
             msg="Get Configuration parameter")
         assert_equal(param_name, config_parameter_dict['name'])
         with TypeCheck('ConfigurationParameter', param) as parameter:
-            parameter.has_field('name', basestring)
+            parameter.has_field('name', six.string_types)
             parameter.has_field('restart_required', bool)
-            parameter.has_field('max', (int, long))
-            parameter.has_field('min', (int, long))
-            parameter.has_field('type', basestring)
-            parameter.has_field('datastore_version_id', unicode)
+            parameter.has_field('max', six.integer_types)
+            parameter.has_field('min', six.integer_types)
+            parameter.has_field('type', six.string_types)
+            parameter.has_field('datastore_version_id', six.text_type)
 
     @test
     def test_configurations_create_invalid_values(self):
@@ -249,7 +256,7 @@ class CreateConfigurations(ConfigurationsTestBase):
 
     @test
     def test_configurations_create_invalid_value_type(self):
-        """Test create configuration with invalild value type."""
+        """Test create configuration with invalid value type."""
         values = '{"key_buffer_size": "this is a string not int"}'
         assert_unprocessable(instance_info.dbaas.configurations.create,
                              CONFIG_NAME, values, CONFIG_DESC)
@@ -280,12 +287,12 @@ class CreateConfigurations(ConfigurationsTestBase):
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 200)
         with TypeCheck('Configuration', result) as configuration:
-            configuration.has_field('name', basestring)
-            configuration.has_field('description', basestring)
+            configuration.has_field('name', six.string_types)
+            configuration.has_field('description', six.string_types)
             configuration.has_field('values', dict)
-            configuration.has_field('datastore_name', basestring)
-            configuration.has_field('datastore_version_id', unicode)
-            configuration.has_field('datastore_version_name', basestring)
+            configuration.has_field('datastore_name', six.string_types)
+            configuration.has_field('datastore_version_id', six.text_type)
+            configuration.has_field('datastore_version_name', six.string_types)
         global configuration_info
         configuration_info = result
         assert_equal(configuration_info.name, CONFIG_NAME)
@@ -390,12 +397,12 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
 
         # check the result field types
         with TypeCheck("configuration", result) as check:
-            check.has_field("id", basestring)
-            check.has_field("name", basestring)
-            check.has_field("description", basestring)
+            check.has_field("id", six.string_types)
+            check.has_field("name", six.string_types)
+            check.has_field("description", six.string_types)
             check.has_field("values", dict)
-            check.has_field("created", basestring)
-            check.has_field("updated", basestring)
+            check.has_field("created", six.string_types)
+            check.has_field("updated", six.string_types)
             check.has_field("instance_count", int)
 
         print(result.values)
@@ -414,7 +421,7 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
 
         with CollectionCheck("configuration_values", result.values) as check:
             # check each item has the correct type according to the rules
-            for (item_key, item_val) in result.values.iteritems():
+            for (item_key, item_val) in result.values.items():
                 print("item_key: %s" % item_key)
                 print("item_val: %s" % item_val)
                 dbaas = instance_info.dbaas
@@ -425,7 +432,7 @@ class AfterConfigurationsCreation(ConfigurationsTestBase):
                 if param.type == 'integer':
                     check.has_element(item_key, int)
                 if param.type == 'string':
-                    check.has_element(item_key, basestring)
+                    check.has_element(item_key, six.string_types)
                 if param.type == 'boolean':
                     check.has_element(item_key, bool)
 
@@ -456,12 +463,12 @@ class ListConfigurations(ConfigurationsTestBase):
         result = instance_info.dbaas.configurations.list()
         for conf in result:
             with TypeCheck("Configuration", conf) as check:
-                check.has_field('id', basestring)
-                check.has_field('name', basestring)
-                check.has_field('description', basestring)
-                check.has_field('datastore_version_id', basestring)
-                check.has_field('datastore_version_name', basestring)
-                check.has_field('datastore_name', basestring)
+                check.has_field('id', six.string_types)
+                check.has_field('name', six.string_types)
+                check.has_field('description', six.string_types)
+                check.has_field('datastore_version_id', six.string_types)
+                check.has_field('datastore_version_name', six.string_types)
+                check.has_field('datastore_name', six.string_types)
 
         exists = [config for config in result if
                   config.id == configuration_info.id]
