@@ -282,8 +282,6 @@ class CreateInstanceQuotaTest(unittest.TestCase):
                       self.test_info.user.tenant_id, quota_dict)
 
     def test_create_too_many_instances(self):
-        raise SkipTest(
-            "Skipping until https://review.openstack.org/#/c/331323 merges")
         instance_quota = 0
         quota_dict = {'instances': instance_quota}
         new_quotas = dbaas_admin.quota.update(self.test_info.user.tenant_id,
@@ -683,7 +681,7 @@ class CreateInstance(object):
         instance_info.dbaas_datastore = CONFIG.dbaas_datastore
         instance_info.dbaas_datastore_version = CONFIG.dbaas_datastore_version
         if VOLUME_SUPPORT:
-            instance_info.volume = {'size': CONFIG.get('trove_volume_size', 1)}
+            instance_info.volume = {'size': CONFIG.get('trove_volume_size', 2)}
         else:
             instance_info.volume = None
 
