@@ -50,7 +50,8 @@ class TestBase(object):
             volume = {'size': size}
         result = self.dbaas.instances.create(name,
                                              instance_info.dbaas_flavor_href,
-                                             volume, [], [])
+                                             volume, [], [],
+                                             nics=instance_info.nics)
         return result.id
 
     def wait_for_instance_status(self, instance_id, status="ACTIVE",
