@@ -24,6 +24,7 @@ from proboscis import before_class
 from proboscis import SkipTest
 from proboscis import test
 from proboscis import TestProgram
+import six
 from troveclient.compat import client as trove_client
 from troveclient.compat import Dbaas
 from troveclient.compat import TroveHTTPClient
@@ -32,7 +33,11 @@ from trove.tests.config import CONFIG
 from trove.tests.examples.client import JsonClient
 from trove.tests.examples.client import SnippetWriter
 
-trove_client._logger.setLevel(logging.CRITICAL)
+# troveclient.compat.client._logger was changed to LOG in 2.11.0
+if hasattr(trove_client, '_logger'):
+    trove_client._logger.setLevel(logging.CRITICAL)
+elif hasattr(trove_client, 'LOG'):
+    trove_client.LOG.setLevel(logging.CRITICAL)
 
 FAKE_INFO = {'m': 30, 's': 0, 'uuid': 'abcdef00-aaaa-aaaa-aaaa-bbbbbbbbbbbb'}
 EXAMPLE_BACKUP_ID = "a9832168-7541-4536-b8d9-a8a9b79cf1b4"
@@ -70,8 +75,9 @@ def set_fake_stuff(uuid=None, minute=None, unique_id=None):
 def monkey_patch_uuid_and_date():
     import uuid
     uuid.uuid4 = get_uuid
+    from trove.common import timeutils
     from trove.common import utils
-    utils.utcnow = get_now
+    timeutils.utcnow = get_now
     utils.generate_uuid = get_uuid
 
 
@@ -1008,10 +1014,12 @@ class MgmtHosts(Example):
                 check.equal(1, len(host.instances))
                 for instance in host.instances:
                     check.equal(instance['status'], 'ACTIVE')
-                    check.true(isinstance(instance['name'], basestring))
-                    check.true(isinstance(instance['id'], basestring))
-                    check.true(isinstance(instance['server_id'], basestring))
-                    check.true(isinstance(instance['tenant_id'], basestring))
+                    check.true(isinstance(instance['name'], six.string_types))
+                    check.true(isinstance(instance['id'], six.string_types))
+                    check.true(isinstance(instance['server_id'],
+                               six.string_types))
+                    check.true(isinstance(instance['tenant_id'],
+                               six.string_types))
 
     @test
     def mgmt_host_update_all(self):
@@ -1118,7 +1126,7 @@ class MgmtInstance(Example):
     @test
     @for_both
     def created(self, result):
-        assert_true(isinstance(result.created, basestring))
+        assert_true(isinstance(result.created, six.string_types))
 
     @test
     def deleted(self):
@@ -1153,8 +1161,8 @@ class MgmtInstance(Example):
         assert_true(isinstance(result.links, list))
         for link in result.links:
             assert_true(isinstance(link, dict))
-            assert_true(isinstance(link['href'], basestring))
-            assert_true(isinstance(link['rel'], basestring))
+            assert_true(isinstance(link['href'], six.string_types))
+            assert_true(isinstance(link['rel'], six.string_types))
 
     @test
     def local_id(self):
@@ -1164,12 +1172,12 @@ class MgmtInstance(Example):
     @test
     @for_both
     def name(self, result):
-        assert_true(isinstance(result.name, basestring))
+        assert_true(isinstance(result.name, six.string_types))
 
     @test
     @for_both
     def server_id(self, result):
-        assert_true(isinstance(result.server['id'], basestring))
+        assert_true(isinstance(result.server['id'], six.string_types))
 
     @test
     @for_both
@@ -1189,7 +1197,7 @@ class MgmtInstance(Example):
     @test
     @for_both
     def updated(self, result):
-        assert_true(isinstance(result.updated, basestring))
+        assert_true(isinstance(result.updated, six.string_types))
 
     @test
     @for_both
