@@ -15,7 +15,6 @@
 
 from hashlib import md5
 from mock import MagicMock, patch
-import httplib
 import json
 import os
 import socket
@@ -24,9 +23,10 @@ import swiftclient.client as swift_client
 import uuid
 
 from oslo_log import log as logging
+import six
+from six.moves import http_client
 from swiftclient import client as swift
 
-from trove.common.i18n import _  # noqa
 
 LOG = logging.getLogger(__name__)
 
@@ -44,7 +44,9 @@ class FakeSwiftClient(object):
 
 class FakeSwiftConnection(object):
     """Logging calls instead of executing."""
-    MANIFEST_HEADER_KEY = 'X-Object-Manifest'
+    MANIFEST_QUERY_STRING_PUT = 'multipart-manifest=put'
+    MANIFEST_QUERY_STRING_DELETE = 'multipart-manifest=delete'
+    COPY_OBJECT_HEADER_KEY = 'X-Copy-From'
     url = 'http://mockswift/v1'
 
     def __init__(self, *args, **kwargs):
@@ -74,23 +76,23 @@ class FakeSwiftConnection(object):
                  'x-account-object-count': '0'}, [])
 
     def head_container(self, container):
-        LOG.debug("fake head_container(%s)" % container)
+        LOG.debug("fake head_container(%s)", container)
         if container == 'missing_container':
             raise swift.ClientException('fake exception',
-                                        http_status=httplib.NOT_FOUND)
+                                        http_status=http_client.NOT_FOUND)
         elif container == 'unauthorized_container':
             raise swift.ClientException('fake exception',
-                                        http_status=httplib.UNAUTHORIZED)
+                                        http_status=http_client.UNAUTHORIZED)
         elif container == 'socket_error_on_head':
             raise socket.error(111, 'ECONNREFUSED')
         pass
 
     def put_container(self, container):
-        LOG.debug("fake put_container(%s)" % container)
+        LOG.debug("fake put_container(%s)", container)
         pass
 
     def get_container(self, container, **kwargs):
-        LOG.debug("fake get_container(%s)" % container)
+        LOG.debug("fake get_container(%s)", container)
         fake_header = None
         fake_body = [{'name': 'backup_001'},
                      {'name': 'backup_002'},
@@ -98,15 +100,18 @@ class FakeSwiftConnection(object):
         return fake_header, fake_body
 
     def head_object(self, container, name):
-        LOG.debug("fake put_container(%(container)s, %(name)s)" %
+        LOG.debug("fake put_container(%(container)s, %(name)s)",
                   {'container': container, 'name': name})
         checksum = md5()
-        if self.manifest_prefix and self.manifest_name == name:
-            for object_name in sorted(self.container_objects.iterkeys()):
+        if self.manifest_name == name:
+            for object_name in sorted(self.container_objects):
                 object_checksum = md5(self.container_objects[object_name])
                 # The manifest file etag for a HEAD or GET is the checksum of
                 # the concatenated checksums.
-                checksum.update(object_checksum.hexdigest())
+                if six.PY3:
+                    checksum.update(object_checksum.hexdigest().encode())
+                else:
+                    checksum.update(object_checksum.hexdigest())
             # this is included to test bad swift segment etags
             if name.startswith("bad_manifest_etag_"):
                 return {'etag': '"this_is_an_intentional_bad_manifest_etag"'}
@@ -120,7 +125,7 @@ class FakeSwiftConnection(object):
         return {'etag': '"%s"' % checksum.hexdigest()}
 
     def get_object(self, container, name, resp_chunk_size=None):
-        LOG.debug("fake get_object(%(container)s, %(name)s)" %
+        LOG.debug("fake get_object(%(container)s, %(name)s)",
                   {'container': container, 'name': name})
         if container == 'socket_error_on_get':
             raise socket.error(111, 'ECONNREFUSED')
@@ -158,23 +163,31 @@ class FakeSwiftConnection(object):
         return (fake_header, fake_object_body)
 
     def put_object(self, container, name, contents, **kwargs):
-        LOG.debug("fake put_object(%(container)s, %(name)s)" %
+        LOG.debug("fake put_object(%(container)s, %(name)s)",
                   {'container': container, 'name': name})
         if container == 'socket_error_on_put':
             raise socket.error(111, 'ECONNREFUSED')
         headers = kwargs.get('headers', {})
+        query_string = kwargs.get('query_string', '')
         object_checksum = md5()
-        if self.MANIFEST_HEADER_KEY in headers:
+        if query_string == self.MANIFEST_QUERY_STRING_PUT:
             # the manifest prefix format is <container>/<prefix> where
             # container is where the object segments are in and prefix is the
             # common prefix for all segments.
-            self.manifest_prefix = headers.get(self.MANIFEST_HEADER_KEY)
             self.manifest_name = name
-            object_checksum.update(contents)
+            if isinstance(contents, six.text_type):
+                object_checksum.update(contents.encode('utf-8'))
+            else:
+                object_checksum.update(contents)
+        elif self.COPY_OBJECT_HEADER_KEY in headers:
+            # this is a copy object operation
+            source_path = headers.get(self.COPY_OBJECT_HEADER_KEY)
+            source_name = source_path.split('/')[1]
+            self.container_objects[name] = self.container_objects[source_name]
         else:
             if hasattr(contents, 'read'):
                 chunk_size = 128
-                object_content = ""
+                object_content = b""
                 chunk = contents.read(chunk_size)
                 while chunk:
                     object_content += chunk
@@ -192,11 +205,11 @@ class FakeSwiftConnection(object):
         return object_checksum.hexdigest()
 
     def post_object(self, container, name, headers={}):
-        LOG.debug("fake post_object(%(container)s, %(name)s, %(head)s)" %
+        LOG.debug("fake post_object(%(container)s, %(name)s, %(head)s)",
                   {'container': container, 'name': name, 'head': str(headers)})
 
     def delete_object(self, container, name):
-        LOG.debug("fake delete_object(%(container)s, %(name)s)" %
+        LOG.debug("fake delete_object(%(container)s, %(name)s)",
                   {'container': container, 'name': name})
         if container == 'socket_error_on_delete':
             raise socket.error(111, 'ECONNREFUSED')
