@@ -13,13 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
-
 from proboscis import SkipTest
 
-from trove.tests.api.instances import CheckInstance, InstanceTestInfo
 from trove.tests.config import CONFIG
 from trove.tests.scenario.helpers.test_helper import DataType
+from trove.tests.scenario.runners.test_runners import CheckInstance
+from trove.tests.scenario.runners.test_runners import InstanceTestInfo
 from trove.tests.scenario.runners.test_runners import TestRunner
 
 
@@ -27,117 +26,99 @@ class InstanceCreateRunner(TestRunner):
 
     def __init__(self):
         super(InstanceCreateRunner, self).__init__()
-        self.init_inst_id = None
+        self.init_inst_info = None
         self.init_inst_dbs = None
         self.init_inst_users = None
         self.init_inst_host = None
         self.init_inst_data = None
-        self.init_config_group_id = None
+        self.init_inst_config_group_id = None
+        self.config_group_id = None
 
     def run_empty_instance_create(
             self, expected_states=['BUILD', 'ACTIVE'], expected_http_code=200):
         name = self.instance_info.name
-        flavor = self._get_instance_flavor()
-        trove_volume_size = CONFIG.get('trove_volume_size', 1)
+        flavor = self.get_instance_flavor()
+        volume_size = self.instance_info.volume_size
 
-        info = self.assert_instance_create(
-            name, flavor, trove_volume_size, [], [], None, None,
+        instance_info = self.assert_instance_create(
+            name, flavor, volume_size, [], [], None, None,
             CONFIG.dbaas_datastore, CONFIG.dbaas_datastore_version,
-            expected_states, expected_http_code, create_helper_user=True)
+            expected_states, expected_http_code, create_helper_user=True,
+            locality='affinity')
 
         # Update the shared instance info.
-        self.instance_info.databases = info.databases
-        self.instance_info.users = info.users
-        self.instance_info.dbaas_datastore = info.dbaas_datastore
-        self.instance_info.dbaas_datastore_version = (info.
-                                                      dbaas_datastore_version)
-        self.instance_info.dbaas_flavor_href = info.dbaas_flavor_href
-        self.instance_info.volume = info.volume
-        self.instance_info.id = info.id
+        self.instance_info.id = instance_info.id
+        self.instance_info.name = instance_info.name
+        self.instance_info.databases = instance_info.databases
+        self.instance_info.users = instance_info.users
+        self.instance_info.dbaas_datastore = instance_info.dbaas_datastore
+        self.instance_info.dbaas_datastore_version = (
+            instance_info.dbaas_datastore_version)
+        self.instance_info.dbaas_flavor_href = instance_info.dbaas_flavor_href
+        self.instance_info.volume = instance_info.volume
+        self.instance_info.helper_user = instance_info.helper_user
+        self.instance_info.helper_database = instance_info.helper_database
 
     def run_initial_configuration_create(self, expected_http_code=200):
-        dynamic_config = self.test_helper.get_dynamic_group()
-        non_dynamic_config = self.test_helper.get_non_dynamic_group()
-        values = dynamic_config or non_dynamic_config
-        if values:
-            json_def = json.dumps(values)
-            result = self.auth_client.configurations.create(
-                'initial_configuration_for_instance_create',
-                json_def,
-                "Configuration group used by instance create tests.",
-                datastore=self.instance_info.dbaas_datastore,
-                datastore_version=self.instance_info.dbaas_datastore_version)
-            self.assert_client_code(expected_http_code)
-
-            self.init_config_group_id = result.id
+        group_id, _ = self.create_initial_configuration(expected_http_code)
+        if group_id:
+            self.config_group_id = group_id
         else:
             raise SkipTest("No groups defined.")
 
     def run_initialized_instance_create(
             self, with_dbs=True, with_users=True, configuration_id=None,
             expected_states=['BUILD', 'ACTIVE'], expected_http_code=200,
-            create_helper_user=True):
+            create_helper_user=True, name_suffix='_init'):
         if self.is_using_existing_instance:
             # The user requested to run the tests using an existing instance.
             # We therefore skip any scenarios that involve creating new
             # test instances.
             raise SkipTest("Using an existing instance.")
 
-        name = self.instance_info.name + '_init'
-        flavor = self._get_instance_flavor()
-        trove_volume_size = CONFIG.get('trove_volume_size', 1)
+        configuration_id = configuration_id or self.config_group_id
+        name = self.instance_info.name + name_suffix
+        flavor = self.get_instance_flavor()
+        volume_size = self.instance_info.volume_size
         self.init_inst_dbs = (self.test_helper.get_valid_database_definitions()
                               if with_dbs else [])
         self.init_inst_users = (self.test_helper.get_valid_user_definitions()
                                 if with_users else [])
-        if configuration_id:
-            self.init_config_group_id = configuration_id
-
-        if (self.init_inst_dbs or self.init_inst_users or
-                self.init_config_group_id):
+        self.init_inst_config_group_id = configuration_id
+        if (self.init_inst_dbs or self.init_inst_users or configuration_id):
             info = self.assert_instance_create(
-                name, flavor, trove_volume_size,
+                name, flavor, volume_size,
                 self.init_inst_dbs, self.init_inst_users,
-                self.init_config_group_id, None,
+                configuration_id, None,
                 CONFIG.dbaas_datastore, CONFIG.dbaas_datastore_version,
                 expected_states, expected_http_code,
                 create_helper_user=create_helper_user)
 
-            self.init_inst_id = info.id
+            self.init_inst_info = info
         else:
             # There is no need to run this test as it's effectively the same as
             # the empty instance test.
             raise SkipTest("No testable initial properties provided.")
 
-    def _get_instance_flavor(self):
-        if self.EPHEMERAL_SUPPORT:
-            flavor_name = CONFIG.values.get('instance_eph_flavor_name',
-                                            'eph.rd-tiny')
-        else:
-            flavor_name = CONFIG.values.get('instance_flavor_name', 'm1.tiny')
-
-        return self.get_flavor(flavor_name)
-
-    def _get_flavor_href(self, flavor):
-        return self.auth_client.find_flavor_self_href(flavor)
-
     def assert_instance_create(
-        self, name, flavor, trove_volume_size,
-        database_definitions, user_definitions,
+            self, name, flavor, trove_volume_size,
+            database_definitions, user_definitions,
             configuration_id, root_password, datastore, datastore_version,
-            expected_states, expected_http_code, create_helper_user=False):
+            expected_states, expected_http_code, create_helper_user=False,
+            locality=None):
         """This assert method executes a 'create' call and verifies the server
         response. It neither waits for the instance to become available
         nor it performs any other validations itself.
         It has been designed this way to increase test granularity
         (other tests may run while the instance is building) and also to allow
-        its reuse in other runners .
+        its reuse in other runners.
         """
-
         databases = database_definitions
         users = [{'name': item['name'], 'password': item['password']}
                  for item in user_definitions]
 
+        instance_info = InstanceTestInfo()
+
         # Here we add helper user/database if any.
         if create_helper_user:
             helper_db_def, helper_user_def, root_def = self.build_helper_defs()
@@ -146,28 +127,26 @@ class InstanceCreateRunner(TestRunner):
                     "Appending a helper database '%s' to the instance "
                     "definition." % helper_db_def['name'])
                 databases.append(helper_db_def)
+                instance_info.helper_database = helper_db_def
             if helper_user_def:
                 self.report.log(
                     "Appending a helper user '%s:%s' to the instance "
                     "definition."
                     % (helper_user_def['name'], helper_user_def['password']))
                 users.append(helper_user_def)
+                instance_info.helper_user = helper_user_def
 
-        instance_info = InstanceTestInfo()
         instance_info.name = name
         instance_info.databases = databases
         instance_info.users = users
         instance_info.dbaas_datastore = CONFIG.dbaas_datastore
         instance_info.dbaas_datastore_version = CONFIG.dbaas_datastore_version
-        instance_info.dbaas_flavor_href = self._get_flavor_href(flavor)
+        instance_info.dbaas_flavor_href = self.get_flavor_href(flavor)
         if self.VOLUME_SUPPORT:
             instance_info.volume = {'size': trove_volume_size}
         else:
             instance_info.volume = None
-
-        shared_network = CONFIG.get('shared_network', None)
-        if shared_network:
-            instance_info.nics = [{'net-id': shared_network}]
+        instance_info.nics = self.instance_info.nics
 
         self.report.log("Testing create instance: %s"
                         % {'name': name,
@@ -186,9 +165,11 @@ class InstanceCreateRunner(TestRunner):
             self.report.log("Using an existing instance: %s" % instance.id)
             self.assert_equal(expected_states[-1], instance.status,
                               "Given instance is in a bad state.")
+            instance_info.name = instance.name
         else:
             self.report.log("Creating a new instance.")
-            instance = self.auth_client.instances.create(
+            client = self.auth_client
+            instance = client.instances.create(
                 instance_info.name,
                 instance_info.dbaas_flavor_href,
                 instance_info.volume,
@@ -198,9 +179,11 @@ class InstanceCreateRunner(TestRunner):
                 configuration=configuration_id,
                 availability_zone="nova",
                 datastore=instance_info.dbaas_datastore,
-                datastore_version=instance_info.dbaas_datastore_version)
-            self.assert_instance_action(
-                instance.id, expected_states[0:1], expected_http_code)
+                datastore_version=instance_info.dbaas_datastore_version,
+                locality=locality)
+            self.assert_client_code(client, expected_http_code)
+            self.assert_instance_action(instance.id, expected_states[0:1])
+            self.register_debug_inst_ids(instance.id)
 
         instance_info.id = instance.id
 
@@ -226,25 +209,52 @@ class InstanceCreateRunner(TestRunner):
                               instance._info['datastore']['version'],
                               "Unexpected instance datastore version")
             self.assert_configuration_group(instance_info.id, configuration_id)
+            if locality:
+                self.assert_equal(locality, instance._info['locality'],
+                                  "Unexpected locality")
 
         return instance_info
 
-    def wait_for_created_instances(self, expected_states=['BUILD', 'ACTIVE']):
+    def run_wait_for_instance(
+            self, expected_states=['BUILD', 'ACTIVE']):
         instances = [self.instance_info.id]
-        if self.init_inst_id:
-            instances.append(self.init_inst_id)
         self.assert_all_instance_states(instances, expected_states)
+        self.instance_info.srv_grp_id = self.assert_server_group_exists(
+            self.instance_info.id)
+        self.wait_for_test_helpers(self.instance_info)
+
+    def run_wait_for_init_instance(
+            self, expected_states=['BUILD', 'ACTIVE']):
+        if self.init_inst_info:
+            instances = [self.init_inst_info.id]
+            self.assert_all_instance_states(instances, expected_states)
+            self.wait_for_test_helpers(self.init_inst_info)
+
+    def wait_for_test_helpers(self, inst_info):
+        self.report.log("Waiting for helper users and databases to be "
+                        "created on instance: %s" % inst_info.id)
+        client = self.auth_client
+        if inst_info.helper_user:
+            self.wait_for_user_create(client, inst_info.id,
+                                      [inst_info.helper_user])
+        if inst_info.helper_database:
+            self.wait_for_database_create(client, inst_info.id,
+                                          [inst_info.helper_database])
+        self.report.log("Test helpers are ready.")
 
     def run_add_initialized_instance_data(self):
-        self.init_inst_data = DataType.small
-        self.init_inst_host = self.get_instance_host(self.instance_info.id)
-        self.test_helper.add_data(self.init_inst_data, self.init_inst_host)
+        if self.init_inst_info:
+            self.init_inst_data = DataType.small
+            self.init_inst_host = self.get_instance_host(
+                self.init_inst_info.id)
+            self.test_helper.add_data(self.init_inst_data, self.init_inst_host)
 
     def run_validate_initialized_instance(self):
-        if self.init_inst_id:
+        if self.init_inst_info:
             self.assert_instance_properties(
-                self.init_inst_id, self.init_inst_dbs, self.init_inst_users,
-                self.init_config_group_id, self.init_inst_data)
+                self.init_inst_info.id, self.init_inst_dbs,
+                self.init_inst_users, self.init_inst_config_group_id,
+                self.init_inst_data)
 
     def assert_instance_properties(
             self, instance_id, expected_dbs_definitions,
@@ -279,47 +289,53 @@ class InstanceCreateRunner(TestRunner):
                               "No configuration group expected")
 
     def assert_database_list(self, instance_id, expected_databases):
-        expected_names = self._get_names(expected_databases)
-        full_list = self.auth_client.databases.list(instance_id)
-        self.assert_is_none(full_list.next,
-                            "Unexpected pagination in the database list.")
-        listed_names = [database.name for database in full_list]
-        self.assert_is_sublist(expected_names, listed_names,
-                               "Mismatch in instance databases.")
+        self.wait_for_database_create(self.auth_client,
+                                      instance_id, expected_databases)
 
     def _get_names(self, definitions):
         return [item['name'] for item in definitions]
 
     def assert_user_list(self, instance_id, expected_users):
-        expected_names = self._get_names(expected_users)
-        full_list = self.auth_client.users.list(instance_id)
-        self.assert_is_none(full_list.next,
-                            "Unexpected pagination in the user list.")
-        listed_names = [user.name for user in full_list]
-        self.assert_is_sublist(expected_names, listed_names,
-                               "Mismatch in instance users.")
-
+        self.wait_for_user_create(self.auth_client,
+                                  instance_id, expected_users)
         # Verify that user definitions include only created databases.
         all_databases = self._get_names(
             self.test_helper.get_valid_database_definitions())
         for user in expected_users:
-            self.assert_is_sublist(
-                self._get_names(user['databases']), all_databases,
-                "Definition of user '%s' specifies databases not included in "
-                "the list of initial databases." % user['name'])
+            if 'databases' in user:
+                self.assert_is_sublist(
+                    self._get_names(user['databases']), all_databases,
+                    "Definition of user '%s' specifies databases not included "
+                    "in the list of initial databases." % user['name'])
 
-    def run_initialized_instance_delete(self, expected_states=['SHUTDOWN'],
-                                        expected_http_code=202):
-        if self.init_inst_id:
-            self.auth_client.instances.delete(self.init_inst_id)
-            self.assert_client_code(expected_http_code)
-            self.assert_all_gone(self.init_inst_id, expected_states[-1])
+    def run_initialized_instance_delete(self, expected_http_code=202):
+        if self.init_inst_info:
+            client = self.auth_client
+            client.instances.delete(self.init_inst_info.id)
+            self.assert_client_code(client, expected_http_code)
         else:
             raise SkipTest("Cleanup is not required.")
 
+    def run_wait_for_init_delete(self, expected_states=['SHUTDOWN']):
+        delete_ids = []
+        if self.init_inst_info:
+            delete_ids.append(self.init_inst_info.id)
+        if delete_ids:
+            self.assert_all_gone(delete_ids, expected_states[-1])
+        else:
+            raise SkipTest("Cleanup is not required.")
+        self.init_inst_info = None
+        self.init_inst_dbs = None
+        self.init_inst_users = None
+        self.init_inst_host = None
+        self.init_inst_data = None
+        self.init_inst_config_group_id = None
+
     def run_initial_configuration_delete(self, expected_http_code=202):
-        if self.init_config_group_id:
-            self.auth_client.configurations.delete(self.init_config_group_id)
-            self.assert_client_code(expected_http_code)
+        if self.config_group_id:
+            client = self.auth_client
+            client.configurations.delete(self.config_group_id)
+            self.assert_client_code(client, expected_http_code)
         else:
             raise SkipTest("Cleanup is not required.")
+        self.config_group_id = None
