@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from trove.tests.scenario.helpers.test_helper import DataType
 from trove.tests.scenario.runners.test_runners import TestRunner
 
 
@@ -21,6 +22,18 @@ class InstanceUpgradeRunner(TestRunner):
     def __init__(self):
         super(InstanceUpgradeRunner, self).__init__()
 
+    def run_add_test_data(self):
+        host = self.get_instance_host(self.instance_info.id)
+        self.test_helper.add_data(DataType.small, host)
+
+    def run_verify_test_data(self):
+        host = self.get_instance_host(self.instance_info.id)
+        self.test_helper.verify_data(DataType.small, host)
+
+    def run_remove_test_data(self):
+        host = self.get_instance_host(self.instance_info.id)
+        self.test_helper.remove_data(DataType.small, host)
+
     def run_instance_upgrade(
             self, expected_states=['UPGRADE', 'ACTIVE'],
             expected_http_code=202):
@@ -28,6 +41,7 @@ class InstanceUpgradeRunner(TestRunner):
         self.report.log("Testing upgrade on instance: %s" % instance_id)
 
         target_version = self.instance_info.dbaas_datastore_version
-        self.auth_client.instances.upgrade(instance_id, target_version)
-        self.assert_instance_action(instance_id, expected_states,
-                                    expected_http_code)
+        client = self.auth_client
+        client.instances.upgrade(instance_id, target_version)
+        self.assert_client_code(client, expected_http_code)
+        self.assert_instance_action(instance_id, expected_states)
