@@ -20,6 +20,7 @@ import netaddr
 import os
 import proboscis
 import six
+import sys
 import time as timer
 import types
 
@@ -248,7 +249,8 @@ class LogOnFail(type):
                 return fn(*args, **kwargs)
             except proboscis.SkipTest:
                 raise
-            except Exception as test_ex:
+            except Exception:
+                (extype, exvalue, extb) = sys.exc_info()
                 msg_prefix = "*** LogOnFail: "
                 if inst_ids:
                     report.log(msg_prefix + "Exception detected, "
@@ -276,7 +278,7 @@ class LogOnFail(type):
 
                 # Only report on the first error that occurs
                 mcs.reset_inst_ids()
-                raise test_ex
+                six.reraise(extype, exvalue, extb)
 
         return wrapper
 
@@ -476,7 +478,7 @@ class TestRunner(object):
             user=user.auth_user,
             key=user.auth_key,
             tenant_name=user.tenant,
-            auth_version='2.0',
+            auth_version='3.0',
             os_options=os_options)
 
     @property
@@ -769,6 +771,9 @@ class TestRunner(object):
     def get_instance_host(self, instance_id=None):
         instance_id = instance_id or self.instance_info.id
         instance = self.get_instance(instance_id)
+        if 'ip' not in instance._info:
+            self.fail('Instance %s with status %s does not have an IP'
+                      ' address.' % (instance_id, instance._info['status']))
         host = self.extract_ipv4s(instance._info['ip'])[0]
         self.report.log("Found host %s for instance %s." % (host, instance_id))
         return host
