@@ -17,12 +17,11 @@
 Tests dealing with HTTP rate-limiting.
 """
 
-import httplib
-
 
 from mock import Mock, MagicMock, patch
 from oslo_serialization import jsonutils
 import six
+from six.moves import http_client
 import webob
 
 from trove.common import limits
@@ -46,6 +45,7 @@ class BaseLimitTestSuite(trove_testtools.TestCase):
 
     def setUp(self):
         super(BaseLimitTestSuite, self).setUp()
+        self.context = trove_testtools.TroveTestContext(self)
         self.absolute_limits = {"max_instances": 55,
                                 "max_volumes": 100,
                                 "max_backups": 40}
@@ -61,7 +61,7 @@ class LimitsControllerTest(BaseLimitTestSuite):
         limit_controller = LimitsController()
 
         req = MagicMock()
-        req.environ = {}
+        req.environ = {'trove.context': self.context}
 
         view = limit_controller.index(req, "test_tenant_id")
         expected = {'limits': [{'verb': 'ABSOLUTE'}]}
@@ -123,7 +123,7 @@ class LimitsControllerTest(BaseLimitTestSuite):
                                        hard_limit=55)}
 
         req = MagicMock()
-        req.environ = {"trove.limits": limits}
+        req.environ = {"trove.limits": limits, 'trove.context': self.context}
 
         with patch.object(QUOTAS, 'get_all_quotas_by_tenant',
                           return_value=abs_limits):
@@ -223,7 +223,7 @@ class LimitMiddlewareTest(BaseLimitTestSuite):
         response = request.get_response(self.app)
         self.assertEqual(413, response.status_int)
 
-        self.assertTrue('Retry-After' in response.headers)
+        self.assertIn('Retry-After', response.headers)
         retry_after = int(response.headers['Retry-After'])
         self.assertAlmostEqual(retry_after, 60, 1)
 
@@ -232,7 +232,7 @@ class LimitMiddlewareTest(BaseLimitTestSuite):
         value = body["overLimit"]["details"].strip()
         self.assertEqual(expected, value)
 
-        self.assertTrue("retryAfter" in body["overLimit"])
+        self.assertIn("retryAfter", body["overLimit"])
         retryAfter = body["overLimit"]["retryAfter"]
         self.assertEqual("60", retryAfter)
 
@@ -497,7 +497,7 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
     def _request_data(self, verb, path):
         """Get data describing a limit request verb/path."""
-        return jsonutils.dumps({"verb": verb, "path": path})
+        return jsonutils.dump_as_bytes({"verb": verb, "path": path})
 
     def _request(self, verb, url, username=None):
         """Make sure that POSTing to the given url causes the given username
@@ -557,21 +557,21 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
 class FakeHttplibSocket(object):
     """
-    Fake `httplib.HTTPResponse` replacement.
+    Fake `http_client.HTTPResponse` replacement.
     """
 
     def __init__(self, response_string):
         """Initialize new `FakeHttplibSocket`."""
-        self._buffer = six.StringIO(response_string)
+        self._buffer = six.BytesIO(response_string)
 
-    def makefile(self, _mode, _other):
+    def makefile(self, _mode, *args):
         """Returns the socket's internal buffer."""
         return self._buffer
 
 
 class FakeHttplibConnection(object):
     """
-    Fake `httplib.HTTPConnection`.
+    Fake `http_client.HTTPConnection`.
     """
 
     def __init__(self, app, host):
@@ -581,11 +581,11 @@ class FakeHttplibConnection(object):
         self.app = app
         self.host = host
 
-    def request(self, method, path, body="", headers=None):
+    def request(self, method, path, body=b"", headers=None):
         """
         Requests made via this connection actually get translated and routed
         into our WSGI app, we then wait for the response and turn it back into
-        an `httplib.HTTPResponse`.
+        an `http_client.HTTPResponse`.
         """
         if not headers:
             headers = {}
@@ -598,8 +598,10 @@ class FakeHttplibConnection(object):
 
         resp = str(req.get_response(self.app))
         resp = "HTTP/1.0 %s" % resp
+        if six.PY3:
+            resp = resp.encode("utf-8")
         sock = FakeHttplibSocket(resp)
-        self.http_response = httplib.HTTPResponse(sock)
+        self.http_response = http_client.HTTPResponse(sock)
         self.http_response.begin()
 
     def getresponse(self):
@@ -613,7 +615,7 @@ def wire_HTTPConnection_to_WSGI(host, app):
 
     After calling this method, when any code calls
 
-    httplib.HTTPConnection(host)
+    http_client.HTTPConnection(host)
 
     the connection object will be a fake.  Its requests will be sent directly
     to the given WSGI app rather than through a socket.
@@ -641,8 +643,9 @@ def wire_HTTPConnection_to_WSGI(host, app):
             else:
                 return self.wrapped(connection_host, *args, **kwargs)
 
-    oldHTTPConnection = httplib.HTTPConnection
-    httplib.HTTPConnection = HTTPConnectionDecorator(httplib.HTTPConnection)
+    oldHTTPConnection = http_client.HTTPConnection
+    http_client.HTTPConnection = HTTPConnectionDecorator(
+        http_client.HTTPConnection)
     return oldHTTPConnection
 
 
@@ -654,7 +657,7 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
     def setUp(self):
         """
         Do some nifty HTTP/WSGI magic which allows for WSGI to be called
-        directly by something like the `httplib` library.
+        directly by something like the `http_client` library.
         """
         super(WsgiLimiterProxyTest, self).setUp()
         self.app = limits.WsgiLimiter(TEST_LIMITS)
@@ -676,12 +679,12 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
         error = error.strip()
 
         self.assertAlmostEqual(float(delay), 60, 1)
-        self.assertEqual("403 Forbidden\n\nOnly 1 GET request(s) can be"
-                         " made to /delayed every minute.", error)
+        self.assertEqual(b"403 Forbidden\n\nOnly 1 GET request(s) can be"
+                         b" made to /delayed every minute.", error)
 
     def tearDown(self):
         # restore original HTTPConnection object
-        httplib.HTTPConnection = self.oldHTTPConnection
+        http_client.HTTPConnection = self.oldHTTPConnection
         super(WsgiLimiterProxyTest, self).tearDown()
 
 
