@@ -28,6 +28,7 @@ from trove.conductor import api as conductor_api
 from trove.guestagent.backup import backupagent
 from trove.guestagent.common import configuration
 from trove.guestagent.common.configuration import ImportOverrideStrategy
+from trove.guestagent.datastore.experimental.redis.service import RedisApp
 from trove.guestagent.strategies.backup.base import BackupRunner
 from trove.guestagent.strategies.backup.base import UnknownBackupType
 from trove.guestagent.strategies.backup.experimental import couchbase_impl
@@ -283,6 +284,8 @@ class BackupAgentTest(trove_testtools.TestCase):
     @patch.object(configuration.ConfigurationManager, 'parse_configuration',
                   Mock(return_value={'dir': '/var/lib/redis',
                                      'dbfilename': 'dump.rdb'}))
+    @patch.object(RedisApp, 'get_config_command_name',
+                  Mock(return_value='fakeconfig'))
     def test_backup_impl_RedisBackup(self, *mocks):
         netutils.get_my_ipv4 = Mock(return_value="1.1.1.1")
         redis_backup = redis_impl.RedisBackup('redisbackup', extra_opts='')
@@ -310,6 +313,26 @@ class BackupAgentTest(trove_testtools.TestCase):
             self.assertIsNone(backup_runner.zip_cmd)
         self.assertEqual('BackupRunner', backup_runner.backup_type)
 
+    @patch('os.killpg')
+    def test_backup_runner_exits_with_exception(self, mock_kill_pg):
+        """This test is for
+           guestagent/strategies/backup/base,
+           ensures that when backup runner exits with an exception,
+           all child processes are also killed.
+        """
+        BackupRunner.cmd = "%s"
+        backup_runner = BackupRunner('sample', cmd='echo command')
+
+        def test_backup_runner_reraise_exception():
+            mock_func = mock.Mock(side_effect=RuntimeError)
+
+            with backup_runner:
+                mock_func()
+
+        self.assertRaises(RuntimeError,
+                          test_backup_runner_reraise_exception)
+        self.assertTrue(mock_kill_pg.called)
+
     @patch.object(conductor_api.API, 'get_client', Mock(return_value=Mock()))
     @patch.object(conductor_api.API, 'update_backup',
                   Mock(return_value=Mock()))
