@@ -61,6 +61,7 @@ class ClusterTest(trove_testtools.TestCase):
         self.cluster = mongodb_api.MongoDbCluster(self.context, self.db_info,
                                                   self.datastore,
                                                   self.datastore_version)
+        self.cluster._server_group_loaded = True
         self.instances = [{'volume_size': 1, 'flavor_id': '1234'},
                           {'volume_size': 1, 'flavor_id': '1234'},
                           {'volume_size': 1, 'flavor_id': '1234'}]
@@ -80,10 +81,10 @@ class ClusterTest(trove_testtools.TestCase):
                           self.datastore,
                           self.datastore_version,
                           [],
-                          None
-                          )
+                          None, None, None)
 
-    def test_create_unequal_flavors(self):
+    @patch.object(remote, 'create_nova_client')
+    def test_create_unequal_flavors(self, mock_client):
         instances = self.instances
         instances[0]['flavor_id'] = '4567'
         self.assertRaises(exception.ClusterFlavorsNotEqual,
@@ -93,8 +94,7 @@ class ClusterTest(trove_testtools.TestCase):
                           self.datastore,
                           self.datastore_version,
                           instances,
-                          None
-                          )
+                          None, None, None)
 
     @patch.object(remote, 'create_nova_client')
     def test_create_unequal_volumes(self,
@@ -110,13 +110,12 @@ class ClusterTest(trove_testtools.TestCase):
                           self.datastore,
                           self.datastore_version,
                           instances,
-                          None
-                          )
+                          None, None, None)
 
     @patch.object(remote, 'create_nova_client')
     def test_create_storage_not_specified(self,
                                           mock_client):
-        class FakeFlavor:
+        class FakeFlavor(object):
             def __init__(self, flavor_id):
                 self.flavor_id = flavor_id
 
@@ -140,8 +139,7 @@ class ClusterTest(trove_testtools.TestCase):
                           self.datastore,
                           self.datastore_version,
                           instances,
-                          None
-                          )
+                          None, None, None)
 
     @patch('trove.cluster.models.LOG')
     def test_delete_bad_task_status(self, mock_logging):
@@ -219,3 +217,7 @@ class ClusterTest(trove_testtools.TestCase):
             task_status=ClusterTasks.ADDING_SHARD)
         mock_task_api.mongodb_add_shard_cluster.assert_called_with(
             self.cluster.id, 'new-shard-id', 'rs2')
+
+    @patch('trove.cluster.models.LOG')
+    def test_upgrade_not_implemented(self, mock_logging):
+        self.assertRaises(exception.BadRequest, self.cluster.upgrade, "foo")
