@@ -65,6 +65,21 @@ class TestClusterController(trove_testtools.TestCase):
         self.add_shard = {
             "add_shard": {}
         }
+        self.grow = {
+            "grow": [
+                {"flavorRef": "7"},
+            ]
+        }
+        self.shrink = {
+            "shrink": [
+                {"id": "e89aa5fd-6b0a-436d-a75c-1545d34d5331"},
+            ]
+        }
+        self.upgrade = {
+            "upgrade": {
+                "datastore_version": "2.4.10"
+            }
+        }
 
     def test_get_schema_create(self):
         schema = self.controller.get_schema('create', self.cluster)
@@ -73,10 +88,30 @@ class TestClusterController(trove_testtools.TestCase):
         self.assertTrue('cluster')
 
     def test_get_schema_action_add_shard(self):
-        schema = self.controller.get_schema('add_shard', self.add_shard)
+        schema = self.controller.get_schema('action', self.add_shard)
         self.assertIsNotNone(schema)
         self.assertIn('add_shard', schema['properties'])
 
+    def test_get_schema_action_grow(self):
+        schema = self.controller.get_schema('action', self.grow)
+        self.assertIsNotNone(schema)
+        self.assertIn('grow', schema['properties'])
+
+    def test_get_schema_action_shrink(self):
+        schema = self.controller.get_schema('action', self.shrink)
+        self.assertIsNotNone(schema)
+        self.assertIn('shrink', schema['properties'])
+
+    def test_get_schema_action_upgrade(self):
+        schema = self.controller.get_schema('action', self.upgrade)
+        self.assertIsNotNone(schema)
+        self.assertIn('upgrade', schema['properties'])
+
+    def test_get_schema_action_invalid(self):
+        schema = self.controller.get_schema('action', {'wow': {}})
+        self.assertIsNotNone(schema)
+        self.assertThat(len(schema.keys()), Is(0))
+
     def test_validate_create(self):
         body = self.cluster
         schema = self.controller.get_schema('create', body)
@@ -85,7 +120,25 @@ class TestClusterController(trove_testtools.TestCase):
 
     def test_validate_add_shard(self):
         body = self.add_shard
-        schema = self.controller.get_schema('add_shard', body)
+        schema = self.controller.get_schema('action', body)
+        validator = jsonschema.Draft4Validator(schema)
+        self.assertTrue(validator.is_valid(body))
+
+    def test_validate_grow(self):
+        body = self.grow
+        schema = self.controller.get_schema('action', body)
+        validator = jsonschema.Draft4Validator(schema)
+        self.assertTrue(validator.is_valid(body))
+
+    def test_validate_shrink(self):
+        body = self.shrink
+        schema = self.controller.get_schema('action', body)
+        validator = jsonschema.Draft4Validator(schema)
+        self.assertTrue(validator.is_valid(body))
+
+    def test_validate_upgrade(self):
+        body = self.upgrade
+        schema = self.controller.get_schema('action', body)
         validator = jsonschema.Draft4Validator(schema)
         self.assertTrue(validator.is_valid(body))
 
@@ -128,11 +181,8 @@ class TestClusterController(trove_testtools.TestCase):
                       error_messages)
         self.assertIn("locality", error_paths)
 
-    @patch.object(Cluster, 'create')
     @patch.object(datastore_models, 'get_datastore_version')
-    def test_create_clusters_disabled(self,
-                                      mock_get_datastore_version,
-                                      mock_cluster_create):
+    def test_create_clusters_disabled(self, mock_get_datastore_version):
         body = self.cluster
         tenant_id = Mock()
         context = trove_testtools.TroveTestContext(self)
@@ -368,10 +418,10 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
         cluster.datastore_version.manager = 'test_dsv'
         mock_cluster_load.return_value = cluster
 
-        self.assertRaisesRegexp(exception.TroveError,
-                                'should have exactly one action specified',
-                                self.controller.action, req,
-                                body, tenant_id, cluster_id)
+        self.assertRaisesRegex(exception.TroveError,
+                               'should have exactly one action specified',
+                               self.controller.action, req,
+                               body, tenant_id, cluster_id)
 
     @patch.object(models.Cluster, 'load')
     def test_controller_action_no_strategy(self,
@@ -392,10 +442,10 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                           datastore_version='test_dsv')
         mock_cluster_load.return_value = cluster
 
-        self.assertRaisesRegexp(exception.TroveError,
-                                'Action do_stuff2 not supported',
-                                self.controller.action, req,
-                                body, tenant_id, cluster_id)
+        self.assertRaisesRegex(exception.TroveError,
+                               'Action do_stuff2 not supported',
+                               self.controller.action, req,
+                               body, tenant_id, cluster_id)
 
     @patch.object(strategy, 'load_api_strategy')
     @patch.object(models.Cluster, 'load')
