@@ -19,6 +19,7 @@ from trove.cluster import models
 from trove.common.strategies.cluster.experimental.mongodb.api import (
     MongoDbCluster)
 from trove.datastore import models as datastore_models
+from trove.instance import models as instance_models
 from trove.tests.unittests import trove_testtools
 
 
@@ -27,12 +28,20 @@ class TestClusterModel(trove_testtools.TestCase):
     @patch.object(datastore_models.Datastore, 'load')
     @patch.object(datastore_models.DatastoreVersion, 'load_by_uuid')
     @patch.object(models.DBCluster, 'find_by')
-    def test_load(self, mock_find_by, mock_load_dsv_by_uuid, mock_ds_load):
+    @patch.object(instance_models.Instances, 'load_all_by_cluster_id')
+    def test_load(self, mock_inst_load, mock_find_by,
+                  mock_load_dsv_by_uuid, mock_ds_load):
         context = trove_testtools.TroveTestContext(self)
         id = Mock()
+        inst_mock = Mock()
+        server_group = Mock()
+        inst_mock.server_group = server_group
+        mock_inst_load.return_value = [inst_mock]
 
         dsv = Mock()
         dsv.manager = 'mongodb'
         mock_load_dsv_by_uuid.return_value = dsv
         cluster = models.Cluster.load(context, id)
         self.assertIsInstance(cluster, MongoDbCluster)
+        self.assertEqual(server_group, cluster.server_group,
+                         "Unexpected server group")
