@@ -256,8 +256,7 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                                       mock_cluster_create,
                                       mock_get_datastore_version):
 
-        cfg.CONF.set_override('cluster_support', False, group='pxc',
-                              enforce_type=True)
+        cfg.CONF.set_override('cluster_support', False, group='pxc')
 
         body = self.cluster
         tenant_id = Mock()
@@ -282,8 +281,7 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                                      mock_get_datastore_version,
                                      mock_cluster_view_data):
 
-        cfg.CONF.set_override('cluster_support', True, group='pxc',
-                              enforce_type=True)
+        cfg.CONF.set_override('cluster_support', True, group='pxc')
 
         body = self.cluster
         tenant_id = Mock()
