@@ -12,8 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from mock import DEFAULT, MagicMock, patch
+from mock import DEFAULT, MagicMock, Mock, patch
 
+from trove.common import utils
 from trove.guestagent import backup
 from trove.guestagent.common import configuration
 from trove.guestagent.common.configuration import ImportOverrideStrategy
@@ -23,19 +24,19 @@ from trove.guestagent.datastore.experimental.redis import (
 from trove.guestagent.datastore.experimental.redis.manager import (
     Manager as RedisManager)
 from trove.guestagent.volume import VolumeDevice
-from trove.tests.unittests import trove_testtools
+from trove.tests.unittests.guestagent.test_datastore_manager import \
+    DatastoreManagerTest
 
 
-class RedisGuestAgentManagerTest(trove_testtools.TestCase):
+class RedisGuestAgentManagerTest(DatastoreManagerTest):
 
     @patch.object(redis_service.RedisApp, '_build_admin_client')
     @patch.object(ImportOverrideStrategy, '_initialize_import_directory')
     def setUp(self, *args, **kwargs):
-        super(RedisGuestAgentManagerTest, self).setUp()
+        super(RedisGuestAgentManagerTest, self).setUp('redis')
         self.patch_ope = patch('os.path.expanduser')
         self.mock_ope = self.patch_ope.start()
         self.addCleanup(self.patch_ope.stop)
-        self.context = trove_testtools.TroveTestContext(self)
         self.replication_strategy = 'RedisSyncReplication'
         self.patch_rs = patch(
             'trove.guestagent.strategies.replication.get_strategy',
@@ -177,6 +178,9 @@ class RedisGuestAgentManagerTest(trove_testtools.TestCase):
                                           'dbfilename': 'dump.rdb'}))
     @patch.object(operating_system, 'chown')
     @patch.object(operating_system, 'create_directory')
+    @patch.object(redis_service.RedisApp,
+                  'get_config_command_name',
+                  Mock(return_value='fakeconfig'))
     def test_create_backup(self, *mocks):
         backup.backup = MagicMock(return_value=None)
         RedisManager().create_backup(self.context, 'backup_id_123')
@@ -191,6 +195,28 @@ class RedisGuestAgentManagerTest(trove_testtools.TestCase):
         self.assertEqual(
             1, mock_replication.backup_required_for_replication.call_count)
 
+    @patch.object(redis_service.RedisApp, 'update_overrides')
+    @patch.object(redis_service.RedisApp, 'remove_overrides')
+    def test_update_overrides(self, remove_config_mock, update_config_mock):
+        self.manager.update_overrides(self.context, 'overrides')
+        remove_config_mock.assert_not_called()
+        update_config_mock.assert_called_once_with(self.context, 'overrides',
+                                                   False)
+
+    @patch.object(redis_service.RedisApp, 'update_overrides')
+    @patch.object(redis_service.RedisApp, 'remove_overrides')
+    def test_update_overrides_with_remove(self, remove_config_mock,
+                                          update_config_mock):
+        self.manager.update_overrides(self.context, 'overrides', True)
+        remove_config_mock.assert_called_once_with()
+        update_config_mock.assert_not_called()
+
+    @patch.object(redis_service.RedisApp, 'apply_overrides')
+    def test_apply_overrides(self, apply_config_mock):
+        self.manager.apply_overrides(self.context, 'overrides')
+        apply_config_mock.assert_called_once_with(self.manager._app.admin,
+                                                  'overrides')
+
     def test_attach_replica(self):
         mock_replication = MagicMock()
         mock_replication.enable_as_slave = MagicMock()
@@ -326,3 +352,26 @@ class RedisGuestAgentManagerTest(trove_testtools.TestCase):
         self.manager._get_repl_info = MagicMock(return_value=repl_info)
         self.manager.wait_for_txn(self.context, expected_txn_id)
         self.manager._get_repl_info.assert_any_call()
+
+    @patch.object(configuration.ConfigurationManager, 'apply_system_override')
+    @patch.object(redis_service.RedisApp, 'apply_overrides')
+    @patch.object(utils, 'generate_random_password',
+                  return_value='password')
+    def test_enable_root(self, *mock):
+        root_user = {'_name': '-',
+                     '_password': 'password'}
+
+        result = self.manager.enable_root(self.context)
+        self.assertEqual(root_user, result)
+
+    @patch.object(redis_service.RedisApp, 'disable_root')
+    def test_disable_root(self, disable_root_mock):
+        self.manager.disable_root(self.context)
+        disable_root_mock.assert_any_call()
+
+    @patch.object(redis_service.RedisApp, 'get_auth_password',
+                  return_value="password")
+    def test_get_root_password(self, get_auth_password_mock):
+        result = self.manager.get_root_password(self.context)
+        self.assertTrue(get_auth_password_mock.called)
+        self.assertEqual('password', result)
