@@ -48,6 +48,25 @@ class ApiTest(trove_testtools.TestCase):
         self.api.client.prepare = Mock(return_value=self.call_context)
         self.call_context.cast = Mock()
 
+    @patch.object(task_api.API, '_transform_obj', Mock(return_value='flv-id'))
+    def test_create_instance(self):
+        flavor = Mock()
+        self.api.create_instance(
+            'inst-id', 'inst-name', flavor, 'img-id', {'name': 'db1'},
+            {'name': 'usr1'}, 'mysql', None, 1, backup_id='bk-id',
+            availability_zone='az', root_password='pwd', nics=['nic-id'],
+            overrides={}, slave_of_id='slv-id', cluster_config={},
+            volume_type='type', modules=['mod-id'], locality='affinity')
+        self._verify_rpc_prepare_before_cast()
+        self._verify_cast(
+            'create_instance', availability_zone='az', backup_id='bk-id',
+            cluster_config={}, databases={'name': 'db1'},
+            datastore_manager='mysql', flavor='flv-id', image_id='img-id',
+            instance_id='inst-id', locality='affinity', modules=['mod-id'],
+            name='inst-name', nics=['nic-id'], overrides={}, packages=None,
+            root_password='pwd', slave_of_id='slv-id', users={'name': 'usr1'},
+            volume_size=1, volume_type='type')
+
     def test_detach_replica(self):
         self.api.detach_replica('some-instance-id')
 
@@ -99,9 +118,17 @@ class ApiTest(trove_testtools.TestCase):
 
     def test_transform_obj(self):
         flavor = Mock()
-        self.assertRaisesRegexp(ValueError,
-                                ('Could not transform %s' % flavor),
-                                self.api._transform_obj, flavor)
+        self.assertRaisesRegex(ValueError,
+                               ('Could not transform %s' % flavor),
+                               self.api._transform_obj, flavor)
+
+    def test_upgrade(self):
+        self.api.upgrade('some-instance-id', 'some-datastore-version')
+
+        self._verify_rpc_prepare_before_cast()
+        self._verify_cast('upgrade',
+                          instance_id='some-instance-id',
+                          datastore_version_id='some-datastore-version')
 
 
 class TestAPI(trove_testtools.TestCase):
