@@ -35,13 +35,12 @@ from proboscis import SkipTest
 from six.moves.urllib.parse import unquote
 from sqlalchemy import create_engine
 from troveclient.compat import Dbaas
-from troveclient.compat import exceptions
 
 from trove.common import cfg
 from trove.common.utils import import_class
 from trove.common.utils import import_object
 from trove.tests.config import CONFIG as test_config
-from trove.tests.util.client import TestClient as TestClient
+from trove.tests.util.client import TestClient
 from trove.tests.util import test_config as CONFIG
 from trove.tests.util.users import Requirements
 
@@ -50,23 +49,6 @@ WHITE_BOX = test_config.white_box
 CONF = cfg.CONF
 
 
-def assert_http_code(expected_http_code, func, *args, **kwargs):
-    try:
-        rtn_value = func(*args, **kwargs)
-        assert_equal(
-            expected_http_code,
-            200,
-            "Expected the function to return http code %s but instead got "
-            "no error (code 200?)." % expected_http_code)
-        return rtn_value
-    except exceptions.ClientException as ce:
-        assert_equal(
-            expected_http_code,
-            ce.code,
-            "Expected the function to return http code %s but instead got "
-            "code %s." % (expected_http_code, ce.code))
-
-
 def create_client(*args, **kwargs):
     """
     Using the User Requirements as arguments, finds a user and grabs a new
@@ -167,13 +149,13 @@ def create_nova_client(user, service_type=None):
     if not service_type:
         service_type = test_config.nova_client['nova_service_type']
     openstack = Client(CONF.nova_client_version,
-                       user.auth_user,
-                       user.auth_key,
-                       project_name=user.tenant,
+                       username=user.auth_user,
+                       password=user.auth_key,
+                       user_domain_name='Default',
+                       project_id=user.tenant_id,
                        auth_url=test_config.nova_client['auth_url'],
                        service_type=service_type, os_cache=False,
                        cacert=test_config.values.get('cacert', None))
-    openstack.authenticate()
     return TestClient(openstack)
 
 
@@ -183,12 +165,13 @@ def create_glance_client(user):
         raise SkipTest("No glance_client info specified in the Test Config "
                        "so this test will be skipped.")
     from glanceclient import Client
-    from keystoneauth1.identity import v2
+    from keystoneauth1.identity import v3
     from keystoneauth1 import session
 
-    auth = v2.Password(username=user.auth_user,
+    auth = v3.Password(username=user.auth_user,
                        password=user.auth_key,
-                       tenant_name=user.tenant,
+                       user_domain_name='Default',
+                       project_id=user.tenant_id,
                        auth_url=test_config.glance_client['auth_url'])
     session = session.Session(auth=auth)
     glance = Client(CONF.glance_client_version, session=session)
